@@ -1,15 +1,15 @@
-/* $Header: /cvsroot/nco/nco/src/nco/mpncra.c,v 1.143 2013/11/06 17:51:13 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/mpncra.c,v 1.150 2014/01/06 06:46:05 zender Exp $ */
 
 /* This single source file may be called as three separate executables:
-   ncra -- netCDF running averager
-   ncea -- netCDF ensemble averager
+   ncra -- netCDF record averager
+   nces -- netCDF ensemble statistics
    ncrcat -- netCDF record concatenator */
 
 /* Purpose: Compute averages or extract series of specified hyperslabs of 
    specfied variables of multiple input netCDF files and output them 
    to a single file. */
 
-/* Copyright (C) 1995--2013 Charlie Zender
+/* Copyright (C) 1995--2014 Charlie Zender
    
    License: GNU General Public License (GPL) Version 3
    The full license text is at http://www.gnu.org/copyleft/gpl.html 
@@ -40,10 +40,10 @@
    ncra -n 3,4,1 -p /ZENDER/tmp -l ${HOME}/nco/data h0001.nc ~/foo.nc
    scp ~/nco/src/nco/ncra.c esmf.ess.uci.edu:nco/src/nco
    
-   ncea in.nc in.nc ~/foo.nc
-   ncea -n 3,4,1 -p ${HOME}/nco/data h0001.nc ~/foo.nc
-   ncea -n 3,4,1 -p ${HOME}/nco/data -l ${HOME} h0001.nc ~/foo.nc
-   ncea -n 3,4,1 -p /ZENDER/tmp -l ${HOME} h0001.nc ~/foo.nc */
+   nces in.nc in.nc ~/foo.nc
+   nces -n 3,4,1 -p ${HOME}/nco/data h0001.nc ~/foo.nc
+   nces -n 3,4,1 -p ${HOME}/nco/data -l ${HOME} h0001.nc ~/foo.nc
+   nces -n 3,4,1 -p /ZENDER/tmp -l ${HOME} h0001.nc ~/foo.nc */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h> /* Autotools tokens */
@@ -152,8 +152,8 @@ main(int argc,char **argv)
   char *optarg_lcl=NULL; /* [sng] Local copy of system optarg */
   char *sng_cnv_rcd=NULL_CEWI; /* [sng] strtol()/strtoul() return code */
 
-  const char * const CVS_Id="$Id: mpncra.c,v 1.143 2013/11/06 17:51:13 zender Exp $"; 
-  const char * const CVS_Revision="$Revision: 1.143 $";
+  const char * const CVS_Id="$Id: mpncra.c,v 1.150 2014/01/06 06:46:05 zender Exp $"; 
+  const char * const CVS_Revision="$Revision: 1.150 $";
   const char * const opt_sht_lst="3467ACcD:d:FHhL:l:n:Oo:p:P:rRSt:v:xY:y:-:";
   
   dmn_sct **dim;
@@ -172,7 +172,7 @@ main(int argc,char **argv)
   int cnk_map=nco_cnk_map_nil; /* [enm] Chunking map */
   int cnk_nbr=0; /* [nbr] Number of chunk sizes */
   int cnk_plc=nco_cnk_plc_nil; /* [enm] Chunking policy */
-  int dfl_lvl=0; /* [enm] Deflate level */
+  int dfl_lvl=NCO_DFL_LVL_UNDEFINED; /* [enm] Deflate level */
   int fl_idx;
   int fl_nbr=0;
   int fl_in_fmt; /* [enm] Input file format */
@@ -213,6 +213,7 @@ main(int argc,char **argv)
   nm_id_sct *xtr_lst=NULL; /* xtr_lst may be alloc()'d from NULL with -c option */
   
   size_t bfr_sz_hnt=NC_SIZEHINT_DEFAULT; /* [B] Buffer size hint */
+  size_t cnk_sz_byt=0UL; /* [B] Chunk size in bytes */
   size_t cnk_sz_scl=0UL; /* [nbr] Chunk size scalar */
   size_t hdr_pad=0UL; /* [B] Pad at end of header section */
   
@@ -268,6 +269,8 @@ main(int argc,char **argv)
       {"chunk_map",required_argument,0,0}, /* [nbr] Chunking map */
       {"cnk_plc",required_argument,0,0}, /* [nbr] Chunking policy */
       {"chunk_policy",required_argument,0,0}, /* [nbr] Chunking policy */
+      {"cnk_byt",required_argument,0,0}, /* [B] Chunk size in bytes */
+      {"chunk_byte",required_argument,0,0}, /* [B] Chunk size in bytes */
       {"cnk_scl",required_argument,0,0}, /* [nbr] Chunk size scalar */
       {"chunk_scalar",required_argument,0,0}, /* [nbr] Chunk size scalar */
       {"cnk_dmn",required_argument,0,0}, /* [nbr] Chunk size */
@@ -361,6 +364,10 @@ main(int argc,char **argv)
 	bfr_sz_hnt=strtoul(optarg,&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
 	if(*sng_cnv_rcd) nco_sng_cnv_err(optarg,"strtoul",sng_cnv_rcd);
       } /* endif cnk */
+      if(!strcmp(opt_crr,"cnk_byt") || !strcmp(opt_crr,"chunk_byte")){
+        cnk_sz_byt=strtoul(optarg,&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
+        if(*sng_cnv_rcd) nco_sng_cnv_err(optarg,"strtoul",sng_cnv_rcd);
+      } /* endif cnk_byt */
       if(!strcmp(opt_crr,"cnk_dmn") || !strcmp(opt_crr,"chunk_dimension")){
 	/* Copy limit argument for later processing */
 	cnk_arg[cnk_nbr]=(char *)strdup(optarg);
@@ -506,7 +513,7 @@ main(int argc,char **argv)
       break;
     case 'y': /* Operation type */
       nco_op_typ_sng=(char *)strdup(optarg);
-      if(nco_prg_id == ncra || nco_prg_id == ncea ) nco_op_typ=nco_op_typ_get(nco_op_typ_sng);
+      if(nco_prg_id == ncra || nco_prg_id == ncfe || nco_prg_id == ncge) nco_op_typ=nco_op_typ_get(nco_op_typ_sng);
       break;
     case '?': /* Print proper usage */
       (void)nco_usg_prn();
@@ -529,7 +536,7 @@ main(int argc,char **argv)
   fl_lst_in=nco_fl_lst_mk(argv,argc,optind,&fl_nbr,&fl_out,&FL_LST_IN_FROM_STDIN);
   
   /* Make uniform list of user-specified chunksizes */
-  if(cnk_nbr > 0) cnk=nco_cnk_prs(cnk_nbr,cnk_arg);
+  if(cnk_nbr > 0) cnk_dmn=nco_cnk_prs(cnk_nbr,cnk_arg);
   
   /* Make uniform list of user-specified dimension limits */
   if(lmt_nbr > 0) lmt=nco_lmt_prs(lmt_nbr,lmt_arg);
@@ -707,7 +714,7 @@ main(int argc,char **argv)
     (void)nco_var_dfn(in_id,fl_out,out_id,var_out,xtr_nbr,(dmn_sct **)NULL,(int)0,nco_pck_plc_nil,nco_pck_map_nil,dfl_lvl);
     
     /* Set chunksize parameters */
-    if(fl_out_fmt == NC_FORMAT_NETCDF4 || fl_out_fmt == NC_FORMAT_NETCDF4_CLASSIC) (void)nco_cnk_sz_set(out_id,lmt_all_lst,nbr_dmn_fl,&cnk_map,&cnk_plc,cnk_sz_scl,cnk,cnk_nbr);
+    if(fl_out_fmt == NC_FORMAT_NETCDF4 || fl_out_fmt == NC_FORMAT_NETCDF4_CLASSIC) (void)nco_cnk_sz_set(out_id,lmt_all_lst,nbr_dmn_fl,&cnk_map,&cnk_plc,cnk_sz_scl,cnk_dmn,cnk_nbr);
     
     /* Turn off default filling behavior to enhance efficiency */
     (void)nco_set_fill(out_id,NC_NOFILL,&fll_md_old);
@@ -759,7 +766,7 @@ main(int argc,char **argv)
       /* Allocate space for only one record */
       var_prc_out[idx]->sz=var_prc[idx]->sz=var_prc[idx]->sz_rec;
     } /* endif */
-    if(nco_prg_id == ncra || nco_prg_id == ncea){
+    if(nco_prg_id == ncra || nco_prg_id == ncfe){
       var_prc_out[idx]->tally=var_prc[idx]->tally=(long *)nco_malloc(var_prc_out[idx]->sz*sizeof(long int));
       (void)nco_zero_long(var_prc_out[idx]->sz,var_prc_out[idx]->tally);
       var_prc_out[idx]->val.vp=(void *)nco_malloc(var_prc_out[idx]->sz*nco_typ_lng(var_prc_out[idx]->type));
@@ -772,18 +779,18 @@ main(int argc,char **argv)
      Pass 1: Workers construct local persistant variable lists
      Open first file
      mpncra and mpncrcat process first record only
-     mpncea ingests complete file
+     mpnces ingests complete file
      Workers create local list of their variables 
      Pass 2: Complete record/file loops with local variable lists
      Workers skip first timestep (mpncra/mpncrcat) 
      Workers process only variables in their local list from Pass 1 
-     This variable persistance is necessary for mpncra and mpncea
+     This variable persistance is necessary for mpncra and mpnces
      since their workers must maintain running tallies for each variable.
      Variable persistance is not necessary for mpncrcat 
      However, we do it anyway to keep mpncrcat and mpncra similar
      mpncrcat writes records as it reads them and finishes after pass 2
      Pass 3: 
-     mpncea and mpncra require a final loop to normalize and write
+     mpnces and mpncra require a final loop to normalize and write
      Write-token for this loop is passed sequentially through the ranks */
   
   /* Begin Pass 1: Workers construct local persistant variable lists */
@@ -802,7 +809,7 @@ main(int argc,char **argv)
   /* Perform various error-checks on input file */
   if(False) (void)nco_fl_cmp_err_chk();
   
-  if(nco_prg_id == ncra || nco_prg_id == ncrcat){ /* ncea jumps to else branch */
+  if(nco_prg_id == ncra || nco_prg_id == ncrcat){ /* ncfe jumps to else branch */
     /* Loop over each record in current file */
     if(nco_dbg_lvl >= nco_dbg_std && lmt_rec->srt > lmt_rec->end) (void)fprintf(stdout,gettext("%s: WARNING %s (input file %d) is superfluous\n"),nco_prg_nm_get(),fl_in,fl_idx);
     idx_rec=lmt_rec->srt;
@@ -915,7 +922,7 @@ main(int argc,char **argv)
 	      if(RAM_OPEN) md_open=NC_WRITE|NC_SHARE|NC_DISKLESS; else md_open=NC_WRITE|NC_SHARE;
 	      rcd=nco_fl_open(fl_out_tmp,md_open,&bfr_sz_hnt,&out_id);
 	      /* Set chunksize parameters */
-	      if(fl_out_fmt == NC_FORMAT_NETCDF4 || fl_out_fmt == NC_FORMAT_NETCDF4_CLASSIC) (void)nco_cnk_sz_set(out_id,lmt_all_lst,nbr_dmn_fl,&cnk_map,&cnk_plc,cnk_sz_scl,cnk,cnk_nbr);
+	      if(fl_out_fmt == NC_FORMAT_NETCDF4 || fl_out_fmt == NC_FORMAT_NETCDF4_CLASSIC) (void)nco_cnk_sz_set(out_id,lmt_all_lst,nbr_dmn_fl,&cnk_map,&cnk_plc,cnk_sz_scl,cnk_dmn,cnk_nbr);
 	      
 	      /* Turn off default filling behavior to enhance efficiency */
 	      nco_set_fill(out_id,NC_NOFILL,&fll_md_old);
@@ -943,7 +950,7 @@ main(int argc,char **argv)
     printf("DEBUG: End of first pass of ncra/ncrcat at node %d\n",prc_rnk);
     
     /* End of ncra, ncrcat section */
-  }else{ /* ncea */
+  }else{ /* ncfe */
     
     if(prc_rnk == rnk_mgr){ /* MPI manager code */
       /* Compensate for incrementing on each worker's first message */
@@ -962,7 +969,7 @@ main(int argc,char **argv)
 	if(msg_tag_typ == msg_tag_wrk_rqs){
 	  var_wrt_nbr++; /* [nbr] Number of variables written */
 	  /* Worker closed output file before sending msg_tag_wrk_rqs */
-	  /* TKN_WRT_FREE=True; ncea does not do file write here */
+	  /* TKN_WRT_FREE=True; ncfe does not do file write here */
 	  
 	  if(idx > nbr_var_prc-1){
 	    msg_bfr[0]=idx_all_wrk_ass; /* [enm] All variables already assigned */
@@ -1012,7 +1019,7 @@ main(int argc,char **argv)
 	} /* !idx_all_wrk_ass */
       } /* while(1) loop requesting work/token in Worker */
     } /* endif Worker */
-  } /* end else ncea */
+  } /* end else ncfe */
   
   if(nco_dbg_lvl > nco_dbg_scl) (void)fprintf(stderr,"\n");
   
@@ -1065,7 +1072,7 @@ main(int argc,char **argv)
     /* Perform various error-checks on input file */
     if(False) (void)nco_fl_cmp_err_chk();
     
-    if(nco_prg_id == ncra || nco_prg_id == ncrcat){ /* ncea jumps to else branch */
+    if(nco_prg_id == ncra || nco_prg_id == ncrcat){ /* ncfe jumps to else branch */
       /* Loop over each record in current file */
       if(nco_dbg_lvl >= nco_dbg_std && lmt_rec->srt > lmt_rec->end) (void)fprintf(stdout,gettext("%s: WARNING %s (input file %d) is superfluous\n"),nco_prg_nm_get(),fl_in,fl_idx);
       for(idx_rec=lmt_rec->srt;idx_rec<=lmt_rec->end;idx_rec+=lmt_rec->srd){
@@ -1170,7 +1177,7 @@ main(int argc,char **argv)
 		if(tkn_wrt_rsp == tkn_wrt_rqs_xcp){
 		  rcd=nco_fl_open(fl_out_tmp,NC_WRITE|NC_SHARE,&bfr_sz_hnt,&out_id);
 		  /* Set chunksize parameters */
-		  if(fl_out_fmt == NC_FORMAT_NETCDF4 || fl_out_fmt == NC_FORMAT_NETCDF4_CLASSIC) (void)nco_cnk_sz_set(out_id,lmt_all_lst,nbr_dmn_fl,&cnk_map,&cnk_plc,cnk_sz_scl,cnk,cnk_nbr);
+		  if(fl_out_fmt == NC_FORMAT_NETCDF4 || fl_out_fmt == NC_FORMAT_NETCDF4_CLASSIC) (void)nco_cnk_sz_set(out_id,lmt_all_lst,nbr_dmn_fl,&cnk_map,&cnk_plc,cnk_sz_scl,cnk_dmn,cnk_nbr);
 		  
 		  /* Turn off default filling behavior to enhance efficiency */
 		  nco_set_fill(out_id,NC_NOFILL,&fll_md_old);
@@ -1229,9 +1236,9 @@ main(int argc,char **argv)
       printf("DEBUG: prc_rnk %d at the end of ncra/rcat\n",prc_rnk);
 #endif /* !ENABLE_MPI */
       /* End of ncra, ncrcat section */
-    }else{ /* ncea */
+    }else{ /* ncfe */
 #ifdef ENABLE_MPI
-      if(prc_rnk != rnk_mgr){ /* Only Worker does the ncea processing */
+      if(prc_rnk != rnk_mgr){ /* Only Worker does the ncfe processing */
 	if(fl_idx == 0){
 	  continue;
 	}else{ /* a loop of idx = stored indices */
@@ -1266,7 +1273,7 @@ main(int argc,char **argv)
 	  } /* end else !fl_idx=0 */
 	} /* !Worker */
 #endif /* !ENABLE_MPI */
-      } /* end else ncea */
+      } /* end else ncfe */
       
       if(nco_dbg_lvl > nco_dbg_scl) (void)fprintf(stderr,"\n");
       
@@ -1280,7 +1287,7 @@ main(int argc,char **argv)
     printf("DEBUG: prc_rnk %d is out of file idx loop\n",prc_rnk); 
 #endif /* !ENABLE_MPI */
     /* Normalize, multiply, etc where necessary */
-    if(nco_prg_id == ncra || nco_prg_id == ncea){
+    if(nco_prg_id == ncra || nco_prg_id == ncfe){
 #ifdef ENABLE_MPI
       if(prc_rnk != rnk_mgr){ /* Only workers have indices of variables to process */
 	for(jdx=0;jdx<lcl_nbr_var;jdx++){
@@ -1347,7 +1354,7 @@ main(int argc,char **argv)
     }
     printf("DEBUG: Mgr shud prnt this too, prc_rnk %d\n",prc_rnk);
 #endif /* !ENABLE_MPI */
-  } /* !ncra/ncea */
+  } /* !ncra/ncfe */
 #ifdef ENABLE_MPI
   printf("DEBUG: After all processing; Before barrier, prc_rnk %d\n",prc_rnk);
   if(prc_rnk == rnk_mgr){ /* Only Manager */
@@ -1373,7 +1380,7 @@ main(int argc,char **argv)
     printf("DEBUG: prc_rnk %d waiting for msg from Mgr for final write\n",prc_rnk);
     MPI_Recv(msg_bfr,msg_bfr_lng,MPI_INT,prc_rnk-1,msg_tag_tkn_wrt_rsp,MPI_COMM_WORLD,&mpi_stt);
     printf("DEBUG: prc_rnk %d got token for final write to %d\n",prc_rnk, out_id);
-    if(nco_prg_id == ncra || nco_prg_id == ncea){
+    if(nco_prg_id == ncra || nco_prg_id == ncfe){
       /* Copy averages to output file and free averaging buffers */
       rcd=nco_fl_open(fl_out_tmp,NC_WRITE|NC_SHARE,&bfr_sz_hnt,&out_id);
       printf("DEBUG: prc_rnk %d opened output file for final write\n",prc_rnk);
@@ -1411,7 +1418,7 @@ main(int argc,char **argv)
   
 #else /* !ENABLE_MPI */
   /* Copy averages to output file and free averaging buffers */
-  if(nco_prg_id == ncra || nco_prg_id == ncea){
+  if(nco_prg_id == ncra || nco_prg_id == ncfe){
     for(idx=0;idx<nbr_var_prc;idx++){
       /* Revert any arithmetic promotion but leave unpacked (for now) */
       var_prc_out[idx]=nco_var_cnf_typ(var_prc_out[idx]->typ_upk,var_prc_out[idx]);
@@ -1459,7 +1466,7 @@ main(int argc,char **argv)
     if(lmt_nbr > 0) lmt=nco_lmt_lst_free(lmt,lmt_nbr);
     /* Free chunking information */
     for(idx=0;idx<cnk_nbr;idx++) cnk_arg[idx]=(char *)nco_free(cnk_arg[idx]);
-    if(cnk_nbr > 0) cnk=nco_cnk_lst_free(cnk,cnk_nbr);
+    if(cnk_nbr > 0) cnk_dmn=nco_cnk_lst_free(cnk_dmn,cnk_nbr);
     /* Free dimension lists */
     if(nbr_dmn_xtr > 0) dim=nco_dmn_lst_free(dim,nbr_dmn_xtr);
     if(nbr_dmn_xtr > 0) dmn_out=nco_dmn_lst_free(dmn_out,nbr_dmn_xtr);
