@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/ncks.c,v 1.695 2014/01/06 06:46:05 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/ncks.c,v 1.710 2014/02/17 23:12:37 zender Exp $ */
 
 /* ncks -- netCDF Kitchen Sink */
 
@@ -53,6 +53,10 @@
    ncks -O -G level3name:-5 -v v7 ~/nco/data/in_grp.nc ~/foo.nc
    ncks -O -v time ~/in_grp.nc ~/foo.nc
    ncks -O --sysconf ~/in_grp.nc ~/foo.nc
+   ncks -C --xml_spr_chr=', ' -v two_dmn_rec_var_sng ~/nco/data/in.nc
+   ncks --cdl -v one_dmn_rec_var ~/nco/data/in.nc
+   ncks --jsn -C -v one_dmn_rec_var ~/nco/data/in.nc
+   ncks --jsn -C -m -v one_dmn_rec_var ~/nco/data/in_grp.nc
    ncks -O -m -M -v Snow_Cover_Monthly_CMG ${DATA}/hdf/MOD10CM.A2007001.005.2007108111758.hdf */
 
 #ifdef HAVE_CONFIG_H
@@ -100,7 +104,7 @@ main(int argc,char **argv)
   nco_bool FORTRAN_IDX_CNV=False; /* Option F */
   nco_bool GET_GRP_INFO=False; /* [flg] Iterate file, get group extended information */
   nco_bool GET_FILE_INFO=False; /* [flg] Get file information (#groups, #dimensions, #attributes, #variables) */
-  nco_bool GET_PRG_INFO=False; /* [flg] Get compiled program information (e.g libraries) */
+  nco_bool GET_PRG_INFO=False; /* [flg] Get compiled program information (e.g., libraries) */
   nco_bool GET_LIST=False; /* [flg] Iterate file, print variables and exit */
   nco_bool GRP_VAR_UNN=False; /* [flg] Select union of specified groups and variables */
   nco_bool HISTORY_APPEND=True; /* Option h */
@@ -109,6 +113,7 @@ main(int argc,char **argv)
   nco_bool PRN_CDL=False; /* [flg] Print CDL */
   nco_bool PRN_HDN=False; /* [flg] Print hidden attributes */
   nco_bool PRN_SRM=False; /* [flg] Print ncStream */
+  nco_bool PRN_JSN=False; /* [flg] Print JSON */
   nco_bool PRN_XML=False; /* [flg] Print XML (NcML) */
   nco_bool PRN_XML_LOCATION=True; /* [flg] Print XML location tag */
   nco_bool PRN_DMN_IDX_CRD_VAL=True; /* [flg] Print leading dimension/coordinate indices/values Option Q */
@@ -151,6 +156,7 @@ main(int argc,char **argv)
   char *opt_crr=NULL; /* [sng] String representation of current long-option name */
   char *optarg_lcl=NULL; /* [sng] Local copy of system optarg */
   char *rec_dmn_nm=NULL; /* [sng] Record dimension name */
+  char *rec_dmn_nm_fix=NULL; /* [sng] Record dimension name (Original input name without _fix prefix) */
   char *smr_sng=NULL; /* [sng] File summary string */
   char *smr_xtn_sng=NULL; /* [sng] File extended summary string */
   char *sng_cnv_rcd=NULL_CEWI; /* [sng] strtol()/strtoul() return code */
@@ -159,8 +165,8 @@ main(int argc,char **argv)
 
   char trv_pth[]="/"; /* [sng] Root path of traversal tree */
 
-  const char * const CVS_Id="$Id: ncks.c,v 1.695 2014/01/06 06:46:05 zender Exp $"; 
-  const char * const CVS_Revision="$Revision: 1.695 $";
+  const char * const CVS_Id="$Id: ncks.c,v 1.710 2014/02/17 23:12:37 zender Exp $"; 
+  const char * const CVS_Revision="$Revision: 1.710 $";
   const char * const opt_sht_lst="34567aABb:CcD:d:FG:g:HhL:l:MmOo:Pp:qQrRs:uv:X:xz-:";
 
   cnk_sct cnk; /* [sct] Chunking structure */
@@ -270,7 +276,10 @@ main(int argc,char **argv)
       {"unn",no_argument,0,0}, /* [flg] Select union of specified groups and variables */
       {"version",no_argument,0,0},
       {"vrs",no_argument,0,0},
-      {"xml",no_argument,0,0}, /* [flg] Print XML (NcML) */
+      {"jsn",no_argument,0,0}, /* [flg] Print JSON */
+      {"json",no_argument,0,0}, /* [flg] Print JSON */
+      {"w10",no_argument,0,0}, /* [flg] Print JSON */
+      {"w10n",no_argument,0,0}, /* [flg] Print JSON */
       {"xml",no_argument,0,0}, /* [flg] Print XML (NcML) */
       {"ncml",no_argument,0,0}, /* [flg] Print XML (NcML) */
       {"xml_no_location",no_argument,0,0}, /* [flg] Omit XML location tag */
@@ -423,6 +432,7 @@ main(int argc,char **argv)
         rec_dmn_nm=(char *)nco_malloc((strlen(fix_pfx)+strlen(optarg)+1L)*sizeof(char));
         rec_dmn_nm=strcpy(rec_dmn_nm,fix_pfx);
         rec_dmn_nm=strcat(rec_dmn_nm,optarg);
+        rec_dmn_nm_fix=strdup(optarg);
       } /* endif fix_rec_dmn */
       if(!strcmp(opt_crr,"fl_fmt") || !strcmp(opt_crr,"file_format")) rcd=nco_create_mode_prs(optarg,&fl_out_fmt);
       if(!strcmp(opt_crr,"get_grp_info") || !strcmp(opt_crr,"grp_info_get")) GET_GRP_INFO=True;
@@ -499,6 +509,7 @@ main(int argc,char **argv)
       } /* endif "vrs" */
       if(!strcmp(opt_crr,"wrt_tmp_fl") || !strcmp(opt_crr,"write_tmp_fl")) WRT_TMP_FL=True;
       if(!strcmp(opt_crr,"no_tmp_fl")) WRT_TMP_FL=False;
+      if(!strcmp(opt_crr,"jsn") || !strcmp(opt_crr,"json") || !strcmp(opt_crr,"w10") || !strcmp(opt_crr,"w10n")) PRN_JSN=True; /* [flg] Print JSON */
       if(!strcmp(opt_crr,"xml") || !strcmp(opt_crr,"ncml")) PRN_XML=True; /* [flg] Print XML (NcML) */
       if(!strcmp(opt_crr,"xml_no_location") || !strcmp(opt_crr,"ncml_no_location")){PRN_XML_LOCATION=False;PRN_XML=True;} /* [flg] Print XML location tag */
       if(!strcmp(opt_crr,"xml_spr_chr")){spr_chr=(char *)strdup(optarg);PRN_XML=True;} /* [flg] Separator for XML character types */
@@ -673,7 +684,7 @@ main(int argc,char **argv)
   (void)nco_bld_trv_tbl(in_id,trv_pth,lmt_nbr,lmt_arg,aux_nbr,aux_arg,MSA_USR_RDR,FORTRAN_IDX_CNV,grp_lst_in,grp_lst_in_nbr,var_lst_in,xtr_nbr,EXTRACT_ALL_COORDINATES,GRP_VAR_UNN,EXCLUDE_INPUT_LIST,EXTRACT_ASSOCIATED_COORDINATES,&flg_dne,trv_tbl);
 
   /* Check if all input -d dimensions were found */ 
-  (void)nco_chk_dmn(lmt_nbr,flg_dne);            
+  (void)nco_chk_dmn(lmt_nbr,flg_dne);    
 
   /* Get number of variables, dimensions, and global attributes in file */
   (void)trv_tbl_inq(&att_glb_nbr,&att_grp_nbr,&att_var_nbr,&dmn_nbr_fl,&dmn_rec_fl,&grp_dpt_fl,&grp_nbr_fl,&var_ntm_fl,&var_nbr_fl,trv_tbl);
@@ -762,7 +773,10 @@ main(int argc,char **argv)
     fl_out_tmp=nco_fl_out_open(fl_out,FORCE_APPEND,FORCE_OVERWRITE,fl_out_fmt,&bfr_sz_hnt,RAM_CREATE,RAM_OPEN,WRT_TMP_FL,&out_id);
     
     /* Create structure with all chunking information */
-    rcd+=nco_cnk_ini(fl_out,cnk_arg,cnk_nbr,cnk_map,cnk_plc,cnk_sz_byt,cnk_sz_scl,&cnk);
+    if(fl_out_fmt == NC_FORMAT_NETCDF4 || fl_out_fmt == NC_FORMAT_NETCDF4_CLASSIC) rcd+=nco_cnk_ini(fl_out,cnk_arg,cnk_nbr,cnk_map,cnk_plc,cnk_sz_byt,cnk_sz_scl,&cnk);
+
+    if(nco_dbg_lvl >= nco_dbg_dev) (void)nco_prn_var(in_id,trv_tbl);       
+    if(nco_dbg_lvl >= nco_dbg_dev) (void)nco_prn_var(out_id,trv_tbl); 
 
     /* Define extracted groups, variables, and attributes in output file */
     (void)nco_xtr_dfn(in_id,out_id,&cnk,dfl_lvl,gpe,md5,PRN_GLB_METADATA,PRN_VAR_METADATA,nco_pck_plc_nil,rec_dmn_nm,trv_tbl);
@@ -819,11 +833,12 @@ main(int argc,char **argv)
     /* No output file was specified so PRN_ tokens refer to screen printing */
     prn_fmt_sct prn_flg;
     prn_flg.cdl=PRN_CDL;
+    prn_flg.jsn=PRN_JSN;
     prn_flg.srm=PRN_SRM;
     prn_flg.xml=PRN_XML;
-    prn_flg.trd=!(PRN_CDL || PRN_XML);
+    prn_flg.trd=!(PRN_CDL || PRN_XML || PRN_JSN);
     if((prn_flg.cdl || prn_flg.xml) && nco_dbg_lvl >= nco_dbg_std) prn_flg.nfo_xtr=True; else prn_flg.nfo_xtr=False;
-    prn_flg.new_fmt=(PRN_CDL || PRN_SRM || PRN_XML || PRN_NEW_FMT);
+    prn_flg.new_fmt=(PRN_CDL || PRN_JSN || PRN_SRM || PRN_XML || PRN_NEW_FMT);
     prn_flg.hdn=PRN_HDN;
     /* CDL must print filename stub */
     if(prn_flg.cdl || prn_flg.xml){
@@ -834,8 +849,8 @@ main(int argc,char **argv)
       if(sfx_ptr) *sfx_ptr='\0';
       prn_flg.fl_stb=fl_nm_stub;
     } /* endif CDL */
-    /* XML needs filename (unless location will be omitted) */
-    if(prn_flg.xml) prn_flg.fl_in=fl_in;
+    /* JSON and XML need filename (unless location will be omitted) */
+    if(prn_flg.xml || prn_flg.jsn) prn_flg.fl_in=fl_in;
     prn_flg.spr_nmr=spr_nmr;
     prn_flg.spr_chr=spr_chr;
     prn_flg.xml_lcn=PRN_XML_LOCATION;
@@ -868,81 +883,90 @@ main(int argc,char **argv)
       prn_flg.PRN_DMN_VAR_NM=True;
       prn_flg.PRN_MSS_VAL_BLANK=True;
     } /* endif */
+    if(prn_flg.jsn){
+      /* JSON either prints metadata or data, not both */
+      if(prn_flg.PRN_VAR_DATA){
+	prn_flg.PRN_VAR_METADATA=False;
+	prn_flg.PRN_GLB_METADATA=False;
+      } /* !PRN_VAR_DATA */
+      if(prn_flg.PRN_GLB_METADATA) prn_flg.PRN_VAR_METADATA=False;
+    } /* endif JSON */
     if(prn_flg.xml) prn_flg.PRN_MSS_VAL_BLANK=False;
 
     /* File summary */
     if(PRN_GLB_METADATA){
-      prn_flg.smr_sng=smr_sng=(char *)nco_malloc(300*sizeof(char)); /* [sng] File summary string */
-      smr_xtn_sng=(char *)nco_malloc(300*sizeof(char)); /* [sng] File extended summary string */
+      prn_flg.smr_sng=smr_sng=(char *)nco_malloc((strlen(fl_in)+300L*sizeof(char))); /* [sng] File summary string */
+      smr_xtn_sng=(char *)nco_malloc(300L*sizeof(char)); /* [sng] File extended summary string */
       if(nco_dbg_lvl > nco_dbg_std) (void)sprintf(smr_xtn_sng," (representation of extended/underlying filetype %s)",nco_fmt_xtn_sng(nco_fmt_xtn_get())); else smr_xtn_sng[0]='\0';
       (void)sprintf(smr_sng,"Summary of %s: filetype = %s%s, %i groups (max. depth = %i), %i dimensions (%i fixed, %i record), %i variables (%i atomic-type, %i non-atomic), %i attributes (%i global, %i group, %i variable)",fl_in,nco_fmt_sng(fl_in_fmt),smr_xtn_sng,grp_nbr_fl,grp_dpt_fl,trv_tbl->nbr_dmn,trv_tbl->nbr_dmn-dmn_rec_fl,dmn_rec_fl,var_nbr_fl+var_ntm_fl,var_nbr_fl,var_ntm_fl,att_glb_nbr+att_grp_nbr+att_var_nbr,att_glb_nbr,att_grp_nbr,att_var_nbr);
       if(!prn_flg.cdl && !prn_flg.xml && !prn_flg.srm) (void)fprintf(stdout,"%s\n\n",smr_sng);
     } /* endif summary */
 
     if(!prn_flg.new_fmt){
-      
+
       /* Traditional printing order/format */
       if(PRN_GLB_METADATA){
-	int dmn_ids_rec[NC_MAX_DIMS]; /* [ID] Record dimension IDs array */
-	int nbr_rec_lcl; /* [nbr] Number of record dimensions visible in root */
-	/* Get unlimited dimension information from input file/group */
-	rcd=nco_inq_unlimdims(in_id,&nbr_rec_lcl,dmn_ids_rec);
-	if(nbr_rec_lcl > 0){
-	  char dmn_nm[NC_MAX_NAME]; 
-	  long rec_dmn_sz;
-	  for(int rec_idx=0;rec_idx<nbr_rec_lcl;rec_idx++){
-	    (void)nco_inq_dim(in_id,dmn_ids_rec[rec_idx],dmn_nm,&rec_dmn_sz);
-	    (void)fprintf(stdout,"Root record dimension %d: name = %s, size = %li\n",rec_idx,dmn_nm,rec_dmn_sz);
-	  } /* end loop over rec_idx */
-	  (void)fprintf(stdout,"\n");
-	} /* NCO_REC_DMN_UNDEFINED */
-	/* Print group attributes recursively */
-	(void)nco_prn_att_trv(in_id,&prn_flg,trv_tbl);
+        int dmn_ids_rec[NC_MAX_DIMS]; /* [ID] Record dimension IDs array */
+        int nbr_rec_lcl; /* [nbr] Number of record dimensions visible in root */
+        /* Get unlimited dimension information from input file/group */
+        rcd=nco_inq_unlimdims(in_id,&nbr_rec_lcl,dmn_ids_rec);
+        if(nbr_rec_lcl > 0){
+          char dmn_nm[NC_MAX_NAME]; 
+          long rec_dmn_sz;
+          for(int rec_idx=0;rec_idx<nbr_rec_lcl;rec_idx++){
+            (void)nco_inq_dim(in_id,dmn_ids_rec[rec_idx],dmn_nm,&rec_dmn_sz);
+            (void)fprintf(stdout,"Root record dimension %d: name = %s, size = %li\n",rec_idx,dmn_nm,rec_dmn_sz);
+          } /* end loop over rec_idx */
+          (void)fprintf(stdout,"\n");
+        } /* NCO_REC_DMN_UNDEFINED */
+        /* Print group attributes recursively */
+        (void)nco_prn_att_trv(in_id,&prn_flg,trv_tbl);
       } /* !PRN_GLB_METADATA */
-      
+
       if(PRN_VAR_METADATA) (void)nco_prn_xtr_mtd(in_id,&prn_flg,trv_tbl);
       if(PRN_VAR_DATA) (void)nco_prn_xtr_val(in_id,&prn_flg,trv_tbl);
       
     }else{ 
-      
+
       /* New file dump format developed 201307 for CDL, TRD, XML, SRM */
-      
+
       if(PRN_SRM){
-	nco_srm_hdr();
-	goto close_and_free;
+        nco_srm_hdr();
+        goto close_and_free;
       } /* !PRN_SRM */
 
       if(ALPHA_BY_FULL_GROUP || ALPHA_BY_STUB_GROUP){
-	rcd+=nco_grp_prn(in_id,trv_pth,&prn_flg,trv_tbl);
+        rcd+=nco_grp_prn(in_id,trv_pth,&prn_flg,trv_tbl);
       }else{
-	trv_sct trv_obj; /* [sct] Traversal table object */
-	for(unsigned int obj_idx=0;obj_idx<trv_tbl->nbr;obj_idx++){
-	  /* Shallow copy to avoid indirection */
-	  trv_obj=trv_tbl->lst[obj_idx];
-	  /* Print this group */
-	  if(trv_obj.nco_typ == nco_obj_typ_grp){
-	    /* Print dimensions defined in this group */
-	    // (void)nco_prn_dmn_xtr(in_id,trv_tbl);
-	    /* Print group attributes */
-	    //if(PRN_GLB_METADATA) (void)nco_prn_grp_att(in_id,trv_tbl);
-	    ;
-	  } /* endif group */
-	  if(trv_obj.nco_typ == nco_obj_typ_var){
-	    if(PRN_VAR_METADATA) (void)nco_prn_xtr_mtd(in_id,&prn_flg,trv_tbl);
-	    if(PRN_VAR_DATA) (void)nco_prn_xtr_val(in_id,&prn_flg,trv_tbl);
-	  } /* endif variable */
-	} /* end loop over obj_idx */
+        trv_sct trv_obj; /* [sct] Traversal table object */
+        for(unsigned int obj_idx=0;obj_idx<trv_tbl->nbr;obj_idx++){
+          /* Shallow copy to avoid indirection */
+          trv_obj=trv_tbl->lst[obj_idx];
+          /* Print this group */
+          if(trv_obj.nco_typ == nco_obj_typ_grp){
+            /* Print dimensions defined in this group */
+            // (void)nco_prn_dmn_xtr(in_id,trv_tbl);
+            /* Print group attributes */
+            //if(PRN_GLB_METADATA) (void)nco_prn_grp_att(in_id,trv_tbl);
+            ;
+          } /* endif group */
+          if(trv_obj.nco_typ == nco_obj_typ_var){
+            if(PRN_VAR_METADATA) (void)nco_prn_xtr_mtd(in_id,&prn_flg,trv_tbl);
+            if(PRN_VAR_DATA) (void)nco_prn_xtr_val(in_id,&prn_flg,trv_tbl);
+          } /* endif variable */
+        } /* end loop over obj_idx */
       } /* end if */
     } /* endif new format */
 
     if(fl_in_dpl) fl_in_dpl=(char *)nco_free(fl_in_dpl);
   } /* !fl_out */
-  
- close_and_free: /* goto close_and_free */
-  
+
+  /* goto close_and_free */
+close_and_free: 
+
   /* Close input netCDF file */
   nco_close(in_id);
-  
+
   /* Remove local copy of file */
   if(FL_RTR_RMT_LCN && RM_RMT_FL_PST_PRC) (void)nco_fl_rm(fl_in);
   
@@ -976,12 +1000,13 @@ main(int argc,char **argv)
     for(idx=0;idx<cnk_nbr;idx++) cnk_arg[idx]=(char *)nco_free(cnk_arg[idx]);
     if(cnk_nbr > 0) cnk.cnk_dmn=(cnk_dmn_sct **)nco_cnk_lst_free(cnk.cnk_dmn,cnk_nbr);
     trv_tbl_free(trv_tbl);
+    for(idx=0;idx<lmt_nbr;idx++) flg_dne[idx].dim_nm=(char *)nco_free(flg_dne[idx].dim_nm);
+    if (flg_dne) flg_dne=(nco_dmn_dne_t *)nco_free(flg_dne);
     if(gpe) gpe=(gpe_sct *)nco_gpe_free(gpe);
     if(md5) md5=(md5_sct *)nco_md5_free(md5);
     if(smr_sng) smr_sng=(char *)nco_free(smr_sng);
     if(smr_xtn_sng) smr_xtn_sng=(char *)nco_free(smr_xtn_sng);
-    for(idx=0;idx<lmt_nbr;idx++) flg_dne[idx].dim_nm=(char *)nco_free(flg_dne[idx].dim_nm);
-    flg_dne=(nco_dmn_dne_t *)nco_free(flg_dne);
+    rec_dmn_nm_fix=(char *)nco_free(rec_dmn_nm_fix);
   } /* !flg_cln */
   
   /* End timer */ 
