@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco.h,v 1.465 2014/01/07 21:42:39 pvicente Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco.h,v 1.489 2014/02/18 06:38:36 pvicente Exp $ */
 
 /* Purpose: netCDF Operator (NCO) definitions */
 
@@ -389,6 +389,8 @@ extern "C" {
 #define NCO_NOERR 1
 /* Internal NCO return code indicating failure */
 #define NCO_ERR 0
+
+
 /* UDUnits return code indicating success */
 #define UDUNITS_NOERR 0
 
@@ -417,7 +419,7 @@ extern "C" {
     ncrcat,
     ncrename,
     ncwa,
-    ncge, /* 20131018: Potential new operator */
+    ncge, /* 20131018: New operator */
     ncmv /* 20131018: Potential new operator */
   }; /* end nco_prg_id enum */
   
@@ -568,16 +570,14 @@ extern "C" {
   
   /* Limit structure */
   typedef struct { /* lmt_sct */
-
     char *nm; /* [sng] Dimension name */
     char *nm_fll; /* [sng] Full dimension name */
     char *grp_nm_fll; /* [sng] Full group where dimension is defined. Added for group support from original netCDF3 */
 
-    /* Following four flags are used only by multi-file operators ncra and ncrcat: */
-    char *drn_sng; /* User-specified string for dimension duration */
     char *max_sng; /* User-specified string for dimension maximum */
     char *min_sng; /* User-specified string for dimension minimum */
     char *mro_sng; /* User-specified string for multi-record output */
+    char *ssc_sng; /* User-specified string for dimension subcycle */
     
     char *rbs_sng; /* Used by ncra, ncrcat to re-base record coordinate (holds unit attribute from first file) */
     char *srd_sng; /* User-specified string for dimension stride */
@@ -585,28 +585,37 @@ extern "C" {
     double max_val; /* Double precision representation of maximum value of coordinate requested or implied */
     double min_val; /* Double precision representation of minimum value of coordinate requested or implied */
     double origin;   /* Used by ncra, ncrcat to re-base record coordinate */
+
     int id; /* Dimension ID */
     int lmt_typ; /* crd_val or dmn_idx */
+
     long cnt; /* # of valid elements in this dimension (including effects of stride and wrapping) */
-    long drn; /* Duration of hyperslab */
+    long ssc; /* Subcycle of hyperslab */
     long end; /* Index to end of hyperslab */
     long max_idx; /* Index of maximum requested value in dimension */
     long min_idx; /* Index of minimum requested value in dimension */
+
+    /* Following four flags are used only by multi-file operators ncra and ncrcat: */
+    long idx_end_max_abs; /* [idx] Maximum allowed index in record dimension (multi-file record dimension only) */
     long rec_dmn_sz; /* [nbr] Number of records in this file (multi-file record dimension only) */
     long rec_in_cml; /* [nbr] Cumulative number of records in all files opened so far (multi-file record dimension only) */
-    long idx_end_max_abs; /* [idx] Maximum allowed index in record dimension (multi-file record dimension only) */
+    long rec_rmn_prv_ssc; /* [nbr] Records remaining-to-be-read to complete subcycle group from previous file (multi-file record dimension only) */
     long rec_skp_ntl_spf; /* [nbr] Records skipped in initial superfluous files (multi-file record dimension only) */
     long rec_skp_vld_prv; /* [nbr] Records skipped since previous good one (multi-file record dimension only) */
-    long rec_rmn_prv_drn; /* [nbr] Records remaining-to-be-read to complete duration group from previous file (multi-file record dimension only) */
+
     long srd; /* Stride of hyperslab */
     long srt; /* Index to start of hyperslab */
+
     nco_bool flg_mro; /* True for multi-record output (used by ncra only) */
     nco_bool flg_input_complete; /* True for multi-file operators when no more files need be opened */
+
     nco_bool is_rec_dmn; /* True if record dimension, else False */
     nco_bool is_usr_spc_lmt; /* True if any part of limit is user-specified, else False */
     nco_bool is_usr_spc_max; /* True if user-specified, else False */
     nco_bool is_usr_spc_min; /* True if user-specified, else False */
+
     nco_cln_typ lmt_cln; /* Used by ncra, ncrcat to store enum of calendar-type attribute */
+
   } lmt_sct;
   
   /* Name ID structure */
@@ -698,7 +707,7 @@ extern "C" {
   typedef struct{ /* aed_sct */
     char *att_nm; /* Name of attribute */
     char *var_nm; /* Name of variable, or NULL for global attribute */
-    int id; /* Variable ID or NC_GLOBAL ( = -1) for global attribute */
+    int id; /* Variable ID or NC_GLOBAL (= -1) for global attribute */
     long sz; /* Number of elements in attribute */
     nc_type type; /* Type of attribute */
     ptr_unn val; /* Pointer to attribute value */
@@ -724,6 +733,7 @@ extern "C" {
     nco_bool cdl; /* [flg] Print CDL */
     nco_bool srm; /* [flg] Print ncStream */
     nco_bool trd; /* [flg] Print traditional NCO format */
+    nco_bool jsn; /* [flg] Print JSON */
     nco_bool xml; /* [flg] Print XML (NcML) */
     nco_bool hdn; /* [flg] Print hidden attributes */
     nco_bool xml_lcn; /* [flg] Print XML location tag */
@@ -830,8 +840,18 @@ extern "C" {
     nco_bool flg_xtr;        /* [flg] Extract dimension */
   } dmn_trv_sct; 
 
+
+  /* Build a list of 'standard_name' 'latitude' and 'longitude' coordinates (Auxiliary Coordinates) */
+  typedef struct{
+    char *nm_fll;              /* [sng] Coordinate full name ('latitude' or 'longitude') */ 
+    int dmn_id;                /* [id] Dimension ID of dimension of 'latitude' and 'longitude' coordinate variables, e.g., lat_gds(gds_crd) */
+    char units[NC_MAX_NAME+1]; /* [sng] Units of 'latitude' and 'longitude' */ 
+    nc_type crd_typ;           /* [enm] netCDF type of both "latitude" and "longitude" */
+    int grp_dpt;               /* [nbr] Depth of group (root = 0) */
+  } aux_crd_sct; 
+
   /* GTT Variable dimensions:
-     Dimension have name and size, and can have an associated variable (coordinate variable) */
+  Dimension have name and size, and can have an associated variable (coordinate variable) */
   typedef struct{ 
     char *dmn_nm_fll;        /* [sng] Full dimension name */
     char *dmn_nm;            /* [sng] Dimension name */
@@ -841,6 +861,12 @@ extern "C" {
     crd_sct *crd;            /* [sct] Pointer to coordinate variable if any */
     dmn_trv_sct *ncd;        /* [sct] Pointer to non-coordinate dimension if any */
     int dmn_id;              /* [ID] Dimension ID; same as dmn_trv_sct.id from nc_inq_vardimid() */
+
+    aux_crd_sct *lat_crd;    /* [lst] Array of 'latitude' coordinates */
+    aux_crd_sct *lon_crd;    /* [lst] Array of 'longitude' coordinates */
+    int nbr_lat_crd;         /* [nbr] Number of items in 'latitude' coordinates array */
+    int nbr_lon_crd;         /* [nbr] Number of items in 'longitude' coordinates array */
+
     /* Following are members only used by transformation operators (non-ncks) */
     nco_bool flg_dmn_avg;    /* [flg] Diferentiate between dimensions to average or keep for this variable (ncwa) */  
     nco_bool flg_rdd;        /* [flg] Retain dimension as degenerate (size 1) (ncwa) */  
@@ -870,6 +896,7 @@ extern "C" {
     nc_type var_typ;                  /* [enm] (For variables only) NetCDF type  */  
     size_t nm_fll_lng;                /* [sng] Length of full name */
     char *grp_nm_fll;                 /* [sng] Full group name (for groups, same as nm_fll) */
+    char *grp_nm;                     /* [sng] Group name (for groups, same as nm) */
     char *nm;                         /* [sng] Relative name (i.e., variable name or last component of path name for groups) */
     size_t nm_lng;                    /* [sng] Length of short name */
     int grp_dpt;                      /* [nbr] Depth of group (root = 0) */
@@ -878,6 +905,7 @@ extern "C" {
     int nbr_rec;                      /* [nbr] Number of record dimensions */
     int nbr_grp;                      /* [nbr] (For groups only) Number of sub-groups */   
     int nbr_var;                      /* [nbr] (For groups only) Number of variables */
+
     nco_bool flg_cf;                  /* [flg] Object matches CF-metadata extraction criteria */
     nco_bool flg_crd;                 /* [flg] Object matches coordinate extraction criteria */
     nco_bool flg_dfl;                 /* [flg] Object meets default subsetting criteria */
@@ -892,6 +920,10 @@ extern "C" {
     nco_bool flg_vsg;                 /* [flg] Variable selected because group matches */
     nco_bool flg_xcl;                 /* [flg] Object matches exclusion criteria */
     nco_bool flg_xtr;                 /* [flg] Extract object */ 
+    nco_bool flg_aux;                 /* [flg] Variable contains auxiliary coordinates */ 
+    nco_bool flg_std_att_lat;         /* [flg] Variable contains 'standard_name' attribute "latitude" */ 
+    nco_bool flg_std_att_lon;         /* [flg] Variable contains 'standard_name' attribute "longitude" */ 
+
     /* Following are members only used by transformation operators (non-ncks)  */
     prc_typ_enm enm_prc_typ;          /* [enm] Processing type enumerator */
     nc_type var_typ_out;              /* [enm] NetCDF type in output file (ncflint) (ncpdq) */  
@@ -932,25 +964,37 @@ extern "C" {
     struct dmn_sct_tag *xrf; /* [sct] Cross-reference to associated dimension structure (usually the structure for dimension on output) */
   } dmn_sct; /* end dmn_sct_tag */
 
-  /* Ensemble group structure (ncge). It contains a name for the group (e.g /cesm/cesm_01) and a list of variables for the group */
+  /* Ensemble group structure (ncge). It contains a name for the group (e.g., /cesm/cesm_01) and a list of variables for the group */
   typedef struct{
     char *mbr_nm_fll;       /* [sng] Goup full name */ 
-    char **var_nm_fll;      /* [sng] List of full variable names for this group (e.g /cesm/cesm_01/tas) */
+    char **var_nm_fll;      /* [sng] List of full variable names for this group (e.g., /cesm/cesm_01/tas) */
     int var_nbr;            /* [nbr] Number of variable for this group (size of above array) */ 
   } nsm_grp_sct; 
 
   /* Ensemble (ncge) */
   typedef struct{
-    char *grp_nm_fll_prn;   /* [sng] Parent group full name (key for ensemble) (e.g /cesm) */
+    char *grp_nm_fll_prn;   /* [sng] Parent group full name (key for ensemble) (e.g., /cesm) */
     nsm_grp_sct *mbr;       /* [sng] List of ensemble group member structs (size is mbr_nbr) */
-    char **var_mbr_fll;     /* [sng] List of variable ensemble members (e.g /cesm/cesm_01/tas) */
-    char **grp_mbr_fll;     /* [sng] List of group ensemble members (e.g /cesm/cesm_01) */
+    char **var_mbr_fll;     /* [sng] List of variable ensemble members (e.g., /cesm/cesm_01/tas) */
+    char **grp_mbr_fll;     /* [sng] List of group ensemble members (e.g., /cesm/cesm_01) */
     int mbr_nbr;            /* [nbr] Number of members (groups) of ensemble (i.e., number in this ensemble in this file) */ 
     int mbr_var_nbr;        /* [nbr] Number of variable members of ensemble */           
     int mbr_srt;            /* [nbr] Member offsets (multi files, keep track of new added members) */ 
     int mbr_end;            /* [nbr] Member offsets (multi files, keep track of new added members) */ 
   } nsm_sct; 
 
+  
+  /* Name structure */
+  typedef struct{ /* nm_sct */
+    char *nm;     /* [sng] Name */
+  } nm_sct;
+
+  /* Name list structure */
+  typedef struct{ /* nm_tbl_sct */
+    nm_sct *lst;  /* [sct] List of nm_sct (char * currently) */
+    int nbr;      /* [nbr] Number of items in "lst" array */
+  } nm_tbl_sct;
+
   /* GTT (Group Traversal Table) structure contains two lists
      1) lst: All objects (variables and groups) in file tree (HDF5 model)
      2) lst_dmn: All unique dimensions (in groups) in file tree (netCDF addition to HDF5) */
@@ -963,11 +1007,10 @@ extern "C" {
     trv_sct *hsh;           /* [hsh] Hash table of all trv_sct objects */
     dmn_sct *dmn_dgn;       /* [sct] (ncwa) Degenerate dimensions */
     int nbr_dmn_dgn;        /* [sct] (ncwa) Number of degenerate dimensions (size of above array) */
-    lmt_sct **lmt_rec;      /* [sct] (ncra) Record dimensions */
-    int nbr_rec;            /* [sct] (ncra) Number of record dimensions (size of above array) */
     int nsm_nbr;            /* [nbr] (ncge) Number of ensembles (i.e., number in first file) */ 
     nsm_sct *nsm;           /* [lst] (ncge) List of ensembles (size is nsm_nbr) */ 
-    char *nsm_sfx;          /* [sng] (ncge) Ensemble suffix (e.g /cesm + _avg). Store here instead of passing as function parameters (ncge only) */
+    char *nsm_sfx;          /* [sng] (ncge) Ensemble suffix (e.g., /cesm + _avg). Store here instead of passing as function parameters (ncge only) */
+    nm_tbl_sct *nsm_skp;    /* [lst] (ncge) Skip list (fixed variables to define at ensemble parent group) */ 
   } trv_tbl_sct;
  
   /* GPE duplicate name check structure */
@@ -975,23 +1018,19 @@ extern "C" {
     char *var_nm_fll; /* [sng] Fully qualified variable name */
   } gpe_nm_sct;
 
-  /* Name structure */
-  typedef struct{ /* nm_sct */
-    char *nm;     /* [sng] Name */
-  } nm_sct;
-
-  /* Name list structure */
-  typedef struct{ /* nm_tbl_sct */
-    nm_sct *lst;  /* [sct] List of nm_sct (char * currently) */
-    int nbr;      /* [nbr] Number of items in "lst" array */
-  } nm_tbl_sct;
 
   /* Common variable names; common defined as same absolute path in 2 files */
   typedef struct{		
-    char *var_nm_fll;            /* [sng] Full path of variable (can be relative) */
+    char *nm;                    /* [sng] A name */
     nco_bool flg_in_fl[2];       /* [flg] Is this name in each file?; files are [0] and [1] */
   } nco_cmn_t;
 
+  /* cell_methods structure */
+  typedef struct{ 
+    char *dmn_nm;   /* [sng] Dimension name */
+    int op_type;    /* [enm] Operation type */
+  } cell_methods_sct; 
+
   /* Limit "lmt_sct" monotonic direction */
   typedef enum {
     decreasing, /* 0 */
@@ -999,12 +1038,12 @@ extern "C" {
     not_checked /* 2 */
   } monotonic_direction_enm;
 
-  /* Structure to check for valid input dimension  */
+   /* Structure to check for valid input dimension  */
   typedef struct {	
     nco_bool flg_dne;           /* [flg] Flag to check if input dimension -d "does not exist" */
     char *dim_nm;               /* [sng] Dimension name */    
   } nco_dmn_dne_t;
-  
+
   /* Initialize default value of each member of var_sct structure in var_dfl_set()
      Fill actual value of var_sct structure in nco_var_fll()
      free() each pointer member of var_sct structure in nco_var_free()
@@ -1059,10 +1098,10 @@ extern "C" {
     nco_bool is_rec_dmn; /* [flg] Is a record dimension/coordinate? */
     size_t sz; /* [nbr] Size of dimension/coordinate */
     nco_bool BASIC_DMN; /* [flg] Limit is same as dimension in input file */
-    long dmn_cnt; /* [nbr] Hyperslabbed size of dimension */ 
+    size_t dmn_cnt; /* [nbr] Hyperslabbed size of dimension */ 
     int id; /* [id] Dimension ID */ 
   } dmn_cmn_sct; 
-  
+
 #ifdef __cplusplus
 } /* end extern "C" */
 #endif /* !__cplusplus */
