@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_att_utl.c,v 1.161 2013/10/22 03:03:45 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_att_utl.c,v 1.171 2014/01/09 00:08:43 zender Exp $ */
 
 /* Purpose: Attribute utilities */
 
-/* Copyright (C) 1995--2013 Charlie Zender
+/* Copyright (C) 1995--2014 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -54,7 +54,7 @@ nco_aed_prc /* [fnc] Process single attribute edit for single variable */
     (void)nco_inq_var(nc_id,var_id,var_nm,(nc_type *)NULL,(int *)NULL,(int *)NULL,&nbr_att);
   } /* end else */
 
-  if(nco_dbg_lvl_get() >= nco_dbg_var) (void)fprintf(stdout,"%s: INFO %s examining variable %s\n",nco_prg_nm_get(),fnc_nm,var_nm);
+  if(nco_dbg_lvl_get() >= nco_dbg_var && nco_dbg_lvl_get() != nco_dbg_dev) (void)fprintf(stdout,"%s: INFO %s examining variable %s\n",nco_prg_nm_get(),fnc_nm,var_nm);
 
   /* Query attribute metadata when attribute name was specified */
   if(aed.att_nm) rcd_inq_att=nco_inq_att_flg(nc_id,var_id,aed.att_nm,&att_typ,&att_sz);
@@ -86,7 +86,7 @@ nco_aed_prc /* [fnc] Process single attribute edit for single variable */
     ptr_unn var_val;
     var_sct *var=NULL_CEWI;
 
-    if(nco_dbg_lvl_get() >= nco_dbg_std) (void)fprintf(stdout,"%s: INFO Replacing missing value data in variable %s\n",nco_prg_nm_get(),var_nm);
+    if(nco_dbg_lvl_get() >= nco_dbg_std && nco_dbg_lvl_get() != nco_dbg_dev) (void)fprintf(stdout,"%s: INFO Replacing missing value data in variable %s\n",nco_prg_nm_get(),var_nm);
 
     /* Take file out of define mode */
     (void)nco_enddef(nc_id);
@@ -155,17 +155,17 @@ nco_aed_prc /* [fnc] Process single attribute edit for single variable */
       /*    case NC_FLOAT: for(idx=0L;idx<var_sz;idx++) {if(var_val.fp[idx] == *mss_val_crr.fp) var_val.fp[idx]=*mss_val_new.fp;} break;*/
       /*    case NC_DOUBLE: for(idx=0L;idx<var_sz;idx++) {if(var_val.dp[idx] == *mss_val_crr.dp) var_val.dp[idx]=*mss_val_new.dp;} break;*/
     case NC_FLOAT: 
-      if(isnormal(*mss_val_crr.fp)){
+      if(isfinite(*mss_val_crr.fp)){
 	for(idx=0L;idx<var_sz;idx++) {if(var_val.fp[idx] == *mss_val_crr.fp) var_val.fp[idx]=*mss_val_new.fp;}
-      }else{ /* Old missing value is NaN-like so comparisons to it are always false---must use macros */
-	for(idx=0L;idx<var_sz;idx++) {if(!isnormal(var_val.fp[idx])) {var_val.fp[idx]=*mss_val_new.fp;}}
+      }else{ /* Old missing value is NaN-like so arithmetic comparisons are always false---must use macros */
+	for(idx=0L;idx<var_sz;idx++) {if(!isfinite(var_val.fp[idx])) var_val.fp[idx]=*mss_val_new.fp;}
       } /* endif NaN */
       break;
     case NC_DOUBLE:
-      if(isnormal(*mss_val_crr.dp)){
+      if(isfinite(*mss_val_crr.dp)){
 	for(idx=0L;idx<var_sz;idx++) {if(var_val.dp[idx] == *mss_val_crr.dp) var_val.dp[idx]=*mss_val_new.dp;}
-      }else{ /* Old missing value is NaN-like so comparisons to it are always false---must use macros */
-	for(idx=0L;idx<var_sz;idx++) {if(!isnormal(var_val.dp[idx])){var_val.dp[idx]=*mss_val_new.dp;}}
+      }else{ /* Old missing value is NaN-like so arithmetic comparisons are always false---must use macros */
+	for(idx=0L;idx<var_sz;idx++) {if(!isfinite(var_val.dp[idx])) var_val.dp[idx]=*mss_val_new.dp;}
       } /* endif NaN */
       break;
     case NC_INT: for(idx=0L;idx<var_sz;idx++) {if(var_val.ip[idx] == *mss_val_crr.ip) var_val.ip[idx]=*mss_val_new.ip;} break;
@@ -239,7 +239,7 @@ nco_aed_prc /* [fnc] Process single attribute edit for single variable */
     /* Rename existing attribute to netCDF4-safe name 
        After modifying missing value attribute with netCDF4-safe name below, 
        we will rename attribute to original missing value name. */
-    if(nco_dbg_lvl_get() >= nco_dbg_var) (void)fprintf(stdout,"%s: INFO %s reports creating, modifying, or overwriting %s attribute %s in netCDF4 file requires re-name trick\n",nco_prg_nm_get(),fnc_nm,var_nm,aed.att_nm);
+    if(nco_dbg_lvl_get() >= nco_dbg_var && nco_dbg_lvl_get() != nco_dbg_dev) (void)fprintf(stdout,"%s: INFO %s reports creating, modifying, or overwriting %s attribute %s in netCDF4 file requires re-name trick\n",nco_prg_nm_get(),fnc_nm,var_nm,aed.att_nm);
     if(rcd_inq_att == NC_NOERR) (void)nco_rename_att(nc_id,var_id,aed.att_nm,att_nm_tmp);
     flg_netCDF4_rename_trick=True; /* [flg] Re-name _FillValue in order to create/modify/overwrite it */
     strcpy(aed.att_nm,att_nm_tmp); 
@@ -321,17 +321,25 @@ nco_att_cpy  /* [fnc] Copy attributes from input netCDF file to output netCDF fi
  const nco_bool PCK_ATT_CPY) /* I [flg] Copy attributes "scale_factor", "add_offset" */
 {
   /* Purpose: Copy attributes from input netCDF file to output netCDF file
-  If var_in_id == NC_GLOBAL, then copy global attributes
-  Otherwise copy only indicated variable's attributes
-  When PCK_ATT_CPY is false, copy all attributes except "scale_factor", "add_offset" */
+     If var_in_id == NC_GLOBAL, then copy global attributes
+     Otherwise copy only indicated variable's attributes
+     When PCK_ATT_CPY is false, copy all attributes except "scale_factor", "add_offset" */
 
   char att_nm[NC_MAX_NAME];
   char var_nm[NC_MAX_NAME];
 
+  int fl_fmt; /* [enm] Output file format */
   int idx;
   int nbr_att;
   int rcd; /* [enm] Return code */
 
+  long att_sz;
+
+  nc_type att_typ_in;
+  nc_type att_typ_out;
+
+  nco_bool flg_autoconvert;
+
   if(var_in_id == NC_GLOBAL){
     (void)nco_inq_natts(in_id,&nbr_att);
     if(nbr_att > NC_MAX_ATTRS) (void)fprintf(stdout,"%s: WARNING Number of global attributes is %d which exceeds number permitted by netCDF NC_MAX_ATTRS = %d\n",nco_prg_nm_get(),nbr_att,NC_MAX_ATTRS);
@@ -341,9 +349,15 @@ nco_att_cpy  /* [fnc] Copy attributes from input netCDF file to output netCDF fi
     if(nbr_att > NC_MAX_ATTRS) (void)fprintf(stdout,"%s: WARNING Variable %s has %d attributes which exceeds number permitted by netCDF NC_MAX_ATTRS = %d\n",nco_prg_nm_get(),var_nm,nbr_att,NC_MAX_ATTRS);
   } /* end else */
 
-  /* Jump back to here if current attribute is treated specially */
+  /* Jump back here if current attribute is treated specially */
   for(idx=0;idx<nbr_att;idx++){
     (void)nco_inq_attname(in_id,var_in_id,idx,att_nm);
+    (void)nco_inq_att(in_id,var_in_id,att_nm,&att_typ_in,&att_sz);
+
+    /* Reset default behavior */
+    flg_autoconvert=False;
+    att_typ_out=att_typ_in;
+
     /* Look for same attribute in output variable in output file */
     rcd=nco_inq_att_flg(out_id,var_out_id,att_nm,(nc_type *)NULL,(long *)NULL);
 
@@ -367,31 +381,63 @@ nco_att_cpy  /* [fnc] Copy attributes from input netCDF file to output netCDF fi
     } /* endif attribute is "scale_factor" or "add_offset" */
 
     /* Inform user when copy will overwrite an existing attribute */
-    if(nco_dbg_lvl_get() >= nco_dbg_std){
+    if(nco_dbg_lvl_get() >= nco_dbg_std && nco_dbg_lvl_get() != nco_dbg_dev){
       if(rcd == NC_NOERR){
         if(var_out_id == NC_GLOBAL){
-          (void)fprintf(stderr,"%s: INFO Overwriting global attribute %s\n",nco_prg_nm_get(),att_nm);
+          (void)fprintf(stderr,"%s: INFO Overwriting global or group attribute %s\n",nco_prg_nm_get(),att_nm);
         }else{
           (void)fprintf(stderr,"%s: INFO Overwriting attribute %s for output variable %s\n",nco_prg_nm_get(),att_nm,var_nm);
         } /* end else */
       } /* end if */
     } /* end if dbg */
 
+    /* File format needed for autoconversion */
+    (void)nco_inq_format(out_id,&fl_fmt);
+
+    /* Allow ncks to autoconvert netCDF4 atomic types to netCDF3 output type ... */
+    if(nco_prg_id_get() == ncks && fl_fmt != NC_FORMAT_NETCDF4 && !nco_typ_nc3(att_typ_in)){
+      att_typ_out=nco_typ_nc4_nc3(att_typ_in);
+      flg_autoconvert=True;
+      if(nco_dbg_lvl_get() >= nco_dbg_std) (void)fprintf(stdout,"%s: INFO Autoconverting %s%s attribute %s from netCDF4 type %s to netCDF3 type %s\n",nco_prg_nm_get(),(var_out_id == NC_GLOBAL) ? "global or group" : "variable ",(var_out_id == NC_GLOBAL) ? "" : var_nm,att_nm,nco_typ_sng(att_typ_in),nco_typ_sng(att_typ_out));
+    } /* !flg_autoconvert */
+
     if(strcmp(att_nm,nco_mss_val_sng_get())){
-      /* Copy all attributes except _FillValue with fast library routine */
-      (void)nco_copy_att(in_id,var_in_id,att_nm,out_id,var_out_id);
+      if(flg_autoconvert){
+	var_sct att_var; /* [sct] Variable structure */
+	var_sct *att_var_ptr=NULL; /* [sct] Variable structure */
+
+	/* Initialize variable structure with minimal info. for nco_var_cnf_typ() */
+	att_var.nm=att_nm;
+	att_var.type=att_typ_in;
+	att_var.has_mss_val=False;
+	att_var.sz=att_sz;
+        att_var.val.vp=(void *)nco_malloc(att_sz*nco_typ_lng(att_typ_in)); /* Pointer to attribute value */
+        (void)nco_get_att(in_id,var_in_id,att_nm,att_var.val.vp,att_typ_in);
+
+	if(att_typ_in == NC_STRING && att_typ_out == NC_CHAR){
+	  /* Special case for string conversion:
+	     Keep first string of existing attribute (netCDF3 output attribute can only hold one string) */
+	  att_var.sz=att_sz=strlen(att_var.val.sngp[0]);
+	  rcd=nco_put_att(out_id,var_out_id,att_nm,att_typ_out,att_sz,att_var.val.sngp[0]);
+	  (void)cast_nctype_void(att_typ_out,&att_var.val);
+	  if(att_var.val.vp) att_var.val.vp=(void *)nco_free(att_var.val.vp);
+	}else{ /* !NC_STRING */
+	  att_var_ptr=nco_var_cnf_typ(att_typ_out,&att_var);
+	  rcd=nco_put_att(out_id,var_out_id,att_nm,att_typ_out,att_sz,att_var_ptr->val.vp);
+	  if(att_var_ptr->val.vp) att_var_ptr->val.vp=nco_free(att_var_ptr->val.vp);
+	} /* !NC_STRING */
+      }else{
+	/* Copy all attributes except _FillValue with fast library routine */
+	(void)nco_copy_att(in_id,var_in_id,att_nm,out_id,var_out_id);
+      } /* !Autoconvert */
     }else{
       /* Convert "_FillValue" attribute to unpacked type then copy 
-      Impose NCO convention that _FillValue is same type as variable,
-      whether variable is packed or not */
+	 Impose NCO convention that _FillValue is same type as variable,
+	 whether variable is packed or not */
       aed_sct aed;
 
-      long att_sz;
       size_t att_lng_in;
 
-      nc_type att_typ_in;
-      nc_type att_typ_out;
-
       ptr_unn mss_tmp;
 
       (void)nco_inq_att(in_id,var_in_id,att_nm,&att_typ_in,&att_sz);
@@ -413,10 +459,12 @@ nco_att_cpy  /* [fnc] Copy attributes from input netCDF file to output netCDF fi
       aed.id=out_id; /* Variable ID or NC_GLOBAL ( = -1) for global attribute */
       aed.sz=att_sz; /* Number of elements in attribute */
 
-      /* Do not convert global attributes or PCK_ATT_CPY */  
-      if(PCK_ATT_CPY || var_out_id==NC_GLOBAL) att_typ_out=att_typ_in; else (void)nco_inq_vartype(out_id,var_out_id,&att_typ_out);
+      if(!flg_autoconvert){
+	/* Do not convert global attributes or PCK_ATT_CPY */  
+	if(PCK_ATT_CPY || var_out_id==NC_GLOBAL) att_typ_out=att_typ_in; else (void)nco_inq_vartype(out_id,var_out_id,&att_typ_out);
+      } /* flg_autoconvert */
 
-      if(att_typ_out==att_typ_in){
+      if(att_typ_out == att_typ_in){
         aed.type=att_typ_out; /* Type of attribute */
         aed.val.vp=(void *)nco_malloc(nco_typ_lng(aed.type)); /* Pointer to attribute value */
         (void)nco_get_att(in_id,var_in_id,att_nm,aed.val.vp,att_typ_out);
@@ -432,7 +480,7 @@ nco_att_cpy  /* [fnc] Copy attributes from input netCDF file to output netCDF fi
       } /* att_typ_out!=att_typ_in */
 
       /* Overwrite mode causes problems with netCDF4 and "_FillValue" 
-      Use create mode instead */
+	 Use create mode instead */
       aed.mode=aed_create;
       (void)nco_aed_prc(out_id,var_out_id,aed); 
       /* Release temporary memory */
@@ -1351,6 +1399,14 @@ nco_prs_rnm_lst /* [fnc] Set old_nm, new_nm elements of rename structure */
     } /* end if */
     
     lng_arg_1=comma_1_cp-rnm_arg[idx]; 
+
+    /* If new name is absolute path, get rid of it (ncrename does in place, same group, changes, so absolute path is redundant) */
+    char *abs_1_cp=strrchr(comma_1_cp,'/');
+    /* Found path separator in new name (string after ',' ) */
+    if (abs_1_cp){
+      comma_1_cp=strrchr(comma_1_cp,'/');
+    }
+
     lng_arg_2=rnm_arg[idx]+strlen(rnm_arg[idx])-comma_1_cp-1; 
     
     /* Exit if length of either argument is zero */
