@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_aux.c,v 1.72 2014/01/08 22:48:16 pvicente Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_aux.c,v 1.80 2014/02/14 05:22:16 zender Exp $ */
 
 /* Copyright (C) 1995--2014 Charlie Zender
    License: GNU General Public License (GPL) Version 3
@@ -228,8 +228,8 @@ nco_aux_evl
   lmt_tpl.is_usr_spc_max=True;
   lmt_tpl.flg_mro=False;
   lmt_tpl.srd_sng=(char *)strdup("1");
-  lmt_tpl.drn_sng=NULL;
-  lmt_tpl.drn_sng=NULL;
+  lmt_tpl.ssc_sng=NULL;
+  lmt_tpl.ssc_sng=NULL;
   lmt_tpl.mro_sng=NULL;
   lmt_tpl.mro_sng=NULL;
   lmt_tpl.is_rec_dmn=0;
@@ -240,7 +240,7 @@ nco_aux_evl
   lmt_tpl.end=0L;
   lmt_tpl.cnt=0L;
   lmt_tpl.srd=1L;
-  lmt_tpl.drn=1L;
+  lmt_tpl.ssc=1L;
 
   /* malloc() lmt structure to return
   No way to know exact size in advance though maximum is about dim_sz/2 */
@@ -369,14 +369,12 @@ nco_aux_prs
 lmt_sct **                           /* O [lst] Auxiliary coordinate limits */
 nco_aux_evl_trv
 (const int nc_id,                    /* I [ID] netCDF file ID */
- const trv_sct * const var_trv,      /* I [sct] Variable object */
  int aux_nbr,                        /* I [sng] Number of auxiliary coordinates */
  char *aux_arg[],                    /* I [sng] Auxiliary coordinates */
  trv_sct *lat_trv,                   /* I [sct] "latitude" variable */
  trv_sct *lon_trv,                   /* I [sct] "longitude" variable */
  const nc_type crd_typ,              /* I [nbr] netCDF type of both "latitude" and "longitude" */
  const char * const units,           /* I [sng] Units of both "latitude" and "longitude" */
- const trv_tbl_sct * const trv_tbl,  /* I [sct] GTT (Group Traversal Table) */
  int *aux_lmt_nbr)                   /* I/O [nbr] Number of coordinate limits */
 {
   /* Purpose: Create lmt structure of slabs of continguous cells that
@@ -424,15 +422,13 @@ nco_aux_evl_trv
   void *vp_lat; /* [dgr] Latitude coordinate array, float or double */
   void *vp_lon; /* [dgr] Longitude coordinate array, float or double */
 
-  nco_bool has_lat_lon;
-
   *aux_lmt_nbr=0;
 
-  /* Obtain group ID from netCDF API using full group name */
+  /* Obtain group ID of 'latitude' and 'longitude' from netCDF API using full group name */
   (void)nco_inq_grp_full_ncid(nc_id,lat_trv->grp_nm_fll,&grp_id_lat);
   (void)nco_inq_grp_full_ncid(nc_id,lon_trv->grp_nm_fll,&grp_id_lon);
 
-  /* Obtain variable ID */
+  /* Obtain variable ID of 'latitude' and 'longitude' */
   (void)nco_inq_varid(grp_id_lat,lat_trv->nm,&lat_id);
   (void)nco_inq_varid(grp_id_lon,lon_trv->nm,&lon_id);
 
@@ -460,8 +456,8 @@ nco_aux_evl_trv
   lmt_tpl.is_usr_spc_max=True;
   lmt_tpl.flg_mro=False;
   lmt_tpl.srd_sng=(char *)strdup("1");
-  lmt_tpl.drn_sng=NULL;
-  lmt_tpl.drn_sng=NULL;
+  lmt_tpl.ssc_sng=NULL;
+  lmt_tpl.ssc_sng=NULL;
   lmt_tpl.mro_sng=NULL;
   lmt_tpl.mro_sng=NULL;
   lmt_tpl.is_rec_dmn=0;
@@ -472,7 +468,7 @@ nco_aux_evl_trv
   lmt_tpl.end=0L;
   lmt_tpl.cnt=0L;
   lmt_tpl.srd=1L;
-  lmt_tpl.drn=1L;
+  lmt_tpl.ssc=1L;
 
   /* malloc() lmt structure to return
   No way to know exact size in advance though maximum is about dim_sz/2 */
@@ -557,8 +553,9 @@ nco_find_lat_lon_trv
  const trv_sct * const var_trv,      /* I [sct] Variable object that contains "standard_name" attribute */
  const char * const attr_val,        /* I [sng] Attribute value to find ( "latitude" or "longitude" ) */
  char **var_nm_fll,                  /* I/O [sng] Full name of variable that has "latitude" or "longitude" attributes */
+ int *dmn_id,                        /* I/O [id] Dimension ID of the diension of "latitude" and "longitude" */
  nc_type *crd_typ,                   /* I/O [enm] netCDF type of both "latitude" and "longitude" */
- char **units)                       /* I/O [sng] Units of both "latitude" and "longitude" */
+ char units[])                       /* I/O [sng] Units of both "latitude" and "longitude" */
 {
   /* Purpose: Find auxiliary coordinate variables that map to latitude/longitude 
      Find variables with standard_name = "latitude" and "longitude"
@@ -571,7 +568,6 @@ nco_find_lat_lon_trv
   const char fnc_nm[]="nco_find_lat_lon_trv()";
 
   char att_nm[NC_MAX_NAME]; /* [sng] Attribute name */
-  char value[NC_MAX_NAME];  /* [sng] Attribute value */
   char var_nm[NC_MAX_NAME];
 
   int grp_id;               /* [id] Group ID */
@@ -580,8 +576,6 @@ nco_find_lat_lon_trv
   int var_att_nbr;          /* [nbr] Number of attributes */
   int var_dmn_nbr;          /* [nbr] Number of dimensions */
 
-  long lenp;
-
   nc_type var_typ;          /* [enm] variable type */
 
   assert(var_trv->nco_typ == nco_obj_typ_var);
@@ -597,12 +591,6 @@ nco_find_lat_lon_trv
 
   assert(var_att_nbr == var_trv->nbr_att);
 
-  /* Make sure CF tag exists. Currently require CF-1.0 value */
-  if(NCO_GET_ATT_CHAR(grp_id,NC_GLOBAL,"Conventions",value) || !strstr(value,"CF-1.")){
-    if(nco_dbg_lvl_get() >= nco_dbg_dev)
-      (void)fprintf(stderr,"%s: WARNING %s reports file \"Convention\" attribute is missing or is present but not of the form \"CF-1.X\". Auxiliary coordinate support (i.e., the -X option) cannot be expected to behave well file does not support CF-1.X metadata conventions. Continuing anyway...\n",nco_prg_nm_get(),fnc_nm);
-  } /* !CF */
-
   /* Loop attributes */
   for(int idx_att=0;idx_att<var_att_nbr;idx_att++){
 
@@ -615,8 +603,6 @@ nco_find_lat_lon_trv
     }
 
     char value[NC_MAX_NAME+1];
-    char *var_nm_lat=NULL; 
-    char *var_nm_lon=NULL;
 
     long lenp;
 
@@ -625,8 +611,6 @@ nco_find_lat_lon_trv
     NCO_GET_ATT_CHAR(grp_id,var_id,"standard_name",value);
     value[lenp]='\0';
 
-    lenp=0;
-
     /* Match parameter name to find ( "latitude" or "longitude" ) */
     if(strcmp(value,attr_val) == 0){
 
@@ -634,10 +618,14 @@ nco_find_lat_lon_trv
       *var_nm_fll=(char *)strdup(var_trv->nm_fll);
 
       /* Get units; assume same for both lat and lon */
-      int rcd=nco_inq_attlen(grp_id,var_id,"units",&lenp);
-      if(rcd != NC_NOERR) nco_err_exit(rcd,"nco_find_lat_lon() reports CF convention requires \"latitude\" to have units attribute\n");
-      *units=(char *)nco_malloc((lenp+1L)*sizeof(char *));
-      NCO_GET_ATT_CHAR(nc_id,var_id,"units",*units);
+      int rcd=nco_inq_attlen_flg(grp_id,var_id,"units",&lenp);
+      if(rcd != NC_NOERR){
+        if(nco_dbg_lvl_get() >= nco_dbg_var){
+        (void)fprintf(stdout,"nco_find_lat_lon() reports CF convention requires \"latitude\" to have units attribute\n");
+        }
+        return False;
+      }
+      NCO_GET_ATT_CHAR(grp_id,var_id,"units",units);
       units[lenp]='\0';
 
       if(var_dmn_nbr > 1) (void)fprintf(stderr,"%s: WARNING %s reports latitude variable %s has %d dimensions. NCO only supports hyperslabbing of auxiliary coordinate variables with a single dimension. Continuing with unpredictable results...\n",nco_prg_nm_get(),fnc_nm,var_nm,var_dmn_nbr);
@@ -645,6 +633,9 @@ nco_find_lat_lon_trv
       /* Assign type; assumed same for both lat and lon */
       *crd_typ=var_typ;
 
+      /* Export the dimension ID */
+      *dmn_id=var_dimid[0];
+
       return True;
 
     } /* Match parameter name to find ( "latitude" or "longitude" ) */
@@ -652,4 +643,5 @@ nco_find_lat_lon_trv
 
   return False;
 
-} /* end nco_find_lat_lon_trv() */
\ No newline at end of file
+} /* end nco_find_lat_lon_trv() */
+
