@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_aux.h,v 1.28 2014/01/08 22:48:16 pvicente Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_aux.h,v 1.33 2014/01/13 03:29:53 pvicente Exp $ */
 
 /* Purpose: Sub-set cell-based grids using auxiliary coordinate variable */
 
@@ -67,14 +67,12 @@ nco_aux_prs
 lmt_sct **                           /* O [lst] Auxiliary coordinate limits */
 nco_aux_evl_trv
 (const int nc_id,                    /* I [ID] netCDF file ID */
- const trv_sct * const var_trv,      /* I [sct] Variable object */
  int aux_nbr,                        /* I [sng] Number of auxiliary coordinates */
  char *aux_arg[],                    /* I [sng] Auxiliary coordinates */
  trv_sct *lat_trv,                   /* I [sct] "latitude" variable */
  trv_sct *lon_trv,                   /* I [sct] "longitude" variable */
  const nc_type crd_typ,              /* I [nbr] netCDF type of both "latitude" and "longitude" */
  const char * const units,           /* I [sng] Units of both "latitude" and "longitude" */
- const trv_tbl_sct * const trv_tbl,  /* I [sct] GTT (Group Traversal Table) */
  int *aux_lmt_nbr);                  /* I/O [nbr] Number of coordinate limits */
 
 nco_bool 
@@ -83,8 +81,10 @@ nco_find_lat_lon_trv
  const trv_sct * const var_trv,      /* I [sct] Variable object that contains "standard_name" attribute */
  const char * const attr_val,        /* I [sng] Attribute value to find ( "latitude" or "longitude" ) */
  char **var_nm_fll,                  /* I/O [sng] Full name of variable that has "latitude" or "longitude" attributes */
+ int *dmn_id,                        /* I/O [id] Dimension ID of the diension of "latitude" and "longitude" */
  nc_type *crd_typ,                   /* I/O [enm] netCDF type of both "latitude" and "longitude" */
- char **units);                      /* I/O [sng] Units of both "latitude" and "longitude" */
+ char units[]);                      /* I/O [sng] Units of both "latitude" and "longitude" */
+
 
 #ifdef __cplusplus
 } /* end extern "C" */
