@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_cnk.c,v 1.101 2014/01/10 00:12:00 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_cnk.c,v 1.119 2014/02/19 21:58:56 zender Exp $ */
 
 /* Purpose: NCO utilities for chunking */
 
@@ -63,6 +63,8 @@ nco_cnk_map_sng_get /* [fnc] Convert chunking map enum to string */
     return "lfp";
   case nco_cnk_map_xst:
     return "xst";
+  case nco_cnk_map_rew:
+    return "rew";
   default: nco_dfl_case_cnk_map_err(); break;
   } /* end switch */
   /* Some compilers, e.g., SGI cc, need return statement to end non-void functions */
@@ -123,7 +125,7 @@ nco_dfl_case_cnk_plc_err(void) /* [fnc] Print error and exit for illegal switch(
 
 int /* [rcd] Return code */
 nco_cnk_ini /* [fnc] Create structure with all chunking information */
-(const char const * fl_out, /* I [sng] Output filename */
+(const char * const fl_out, /* I [sng] Output filename */
  CST_X_PTR_CST_PTR_CST_Y(char,cnk_arg), /* I [sng] List of user-specified chunksizes */
  const int cnk_nbr, /* I [nbr] Number of chunksizes specified */
  const int cnk_map, /* I [enm] Chunking map */
@@ -150,7 +152,7 @@ nco_cnk_ini /* [fnc] Create structure with all chunking information */
   if(cnk_nbr > 0 || cnk_sz_byt > 0UL || cnk_sz_scl > 0UL || cnk_map != nco_cnk_map_nil || cnk_plc != nco_cnk_plc_nil) cnk->flg_usr_rqs=True;
 
   /* Chunks are atomic unit of HDF5 read/write
-     Variables are compressed and checksummed one chunk at-a-time
+     Variables are compressed and check-summed one chunk at-a-time
      Set NCO_CNK_SZ_BYT_DFL to system blocksize, if known
      Setting chunksize equal to system blocksize thought to minimize disk head movement, be most efficient 
      Blocksize is related to default buffer; check this with
@@ -236,17 +238,17 @@ nco_cnk_prs /* [fnc] Create chunking structures with name and chunksize elements
        as branch for which no hyperslab along that dimension was set. */
     cnk_dmn[idx]=(cnk_dmn_sct *)nco_malloc(sizeof(cnk_dmn_sct));
     cnk_dmn[idx]->nm=NULL;
+    cnk_dmn[idx]->nm_fll=NULL;
     cnk_dmn[idx]->is_usr_spc_cnk=True; /* True if any part of limit is user-specified, else False */
-    
-    /* Fill-in structure */
-    cnk_dmn[idx]->nm=arg_lst[0];
+
+    /* Parse input name into a temporary string and inquire if name is absolute or relative */
+    char *sng_tmp=arg_lst[0];
+    nco_bool is_fll_pth=nco_is_fll_pth(sng_tmp);
+    if(is_fll_pth) cnk_dmn[idx]->nm_fll=(char *)strdup(sng_tmp); else cnk_dmn[idx]->nm=(char *)strdup(sng_tmp);
+
     /* 20130711: Debian Mayhem project bug #716602 shows unsanitized input can cause core-dump _inside_ strtoul() */
     cnk_dmn[idx]->sz=strtoul(arg_lst[1],&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
-    if(*sng_cnv_rcd) nco_sng_cnv_err(arg_lst[1],"strtoul",sng_cnv_rcd);
-    
-    /* Placeholder for full dimension name 
-       20140102: Simpliy copy stub name for now. Replace by full dimension name after output dimensions defined */
-    cnk_dmn[idx]->nm_fll=(char *)strdup(cnk_dmn[idx]->nm);
+    if(*sng_cnv_rcd) nco_sng_cnv_err(arg_lst[1],"strtoul",sng_cnv_rcd);   
 
     /* Free current pointer array to strings
        Strings themselves are untouched and will be free()'d with chunk structures 
@@ -266,9 +268,8 @@ nco_cnk_lst_free /* [fnc] Free memory associated with chunking structure list */
   /* Purpose: Free all memory associated with dynamically allocated chunking structure list */
   int idx;
 
-  for(idx=0;idx<cnk_nbr;idx++){
+  for(idx=0;idx<cnk_nbr;idx++) 
     cnk_lst[idx]=nco_cnk_dmn_free(cnk_lst[idx]);
-  } /* end loop over idx */
 
   /* Free structure pointer last */
   cnk_lst=(cnk_dmn_sct **)nco_free(cnk_lst);
@@ -319,6 +320,8 @@ nco_cnk_map_get /* [fnc] Convert user-specified chunking map to key */
   if(!strcmp(nco_cnk_map_sng,"cnk_map_lfp")) return nco_cnk_map_lfp;
   if(!strcmp(nco_cnk_map_sng,"xst")) return nco_cnk_map_xst;
   if(!strcmp(nco_cnk_map_sng,"cnk_map_xst")) return nco_cnk_map_xst;
+  if(!strcmp(nco_cnk_map_sng,"rew")) return nco_cnk_map_rew;
+  if(!strcmp(nco_cnk_map_sng,"cnk_map_rew")) return nco_cnk_map_rew;
 
   (void)fprintf(stderr,"%s: ERROR %s reports unknown user-specified chunking map %s\n",nco_prg_nm_get(),fnc_nm,nco_cnk_map_sng);
   nco_exit(EXIT_FAILURE);
@@ -492,7 +495,7 @@ nco_cnk_sz_set /* [fnc] Set chunksize parameters */
 
   nco_bool flg_cnk=False; /* [flg] Chunking requested */
   nco_bool is_rec_var; /* [flg] Record variable */
-  nco_bool is_chk_var; /* [flg] Checksummed variable */
+  nco_bool is_chk_var; /* [flg] Check-summed variable */
   nco_bool is_cmp_var; /* [flg] Compressed variable */
   nco_bool is_chunked; /* [flg] Chunked variable */
   nco_bool must_be_chunked; /* [flg] Variable must be chunked */
@@ -567,7 +570,7 @@ nco_cnk_sz_set /* [fnc] Set chunksize parameters */
     srg_typ=NC_CONTIGUOUS; /* [enm] Storage type */
     cnk_sz=(size_t *)NULL; /* [nbr] Chunksize list */
     is_rec_var=False; /* [flg] Record variable */
-    is_chk_var=False; /* [flg] Checksummed variable */
+    is_chk_var=False; /* [flg] Check-summed variable */
     is_cmp_var=False; /* [flg] Compressed variable */
     is_chunked=False; /* [flg] Chunked variable */
 
@@ -594,7 +597,7 @@ nco_cnk_sz_set /* [fnc] Set chunksize parameters */
     (void)nco_inq_var_deflate(nc_id,var_idx,NULL,&deflate,NULL);
     if(deflate) is_cmp_var=True; 
 
-    /* Is variable checksummed? */
+    /* Is variable check-summed? */
     (void)nco_inq_var_fletcher32(nc_id,var_idx,&chk_typ);
     if(chk_typ != NC_NOCHECKSUM) is_chk_var=True;
 
@@ -612,7 +615,7 @@ nco_cnk_sz_set /* [fnc] Set chunksize parameters */
       /* If variable is chunked */
       if(is_chunked){
 	if(must_be_chunked){
-	  if(nco_dbg_lvl_get() >= nco_dbg_var) (void)fprintf(stderr,"%s: INFO %s %s must be chunked (record, compressed, or checksummed variable)\n",nco_prg_nm_get(),fnc_nm,var_nm);
+	  if(nco_dbg_lvl_get() >= nco_dbg_var) (void)fprintf(stderr,"%s: INFO %s %s must be chunked (record, compressed, or check-summed variable)\n",nco_prg_nm_get(),fnc_nm,var_nm);
 	}else{
 	  /* Turn-off chunking for this variable */
 	  if(nco_dbg_lvl_get() >= nco_dbg_var) (void)fprintf(stderr,"%s: INFO %s unchunking %s\n",nco_prg_nm_get(),fnc_nm,var_nm);
@@ -750,20 +753,16 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
 (const int grp_id_in, /* I [id] netCDF group ID in input file */
  const int grp_id_out, /* I [id] netCDF group ID in output file */
  const cnk_sct * const cnk, /* I [sct] Chunking structure */
- const char * const nm_var,  /* I [sng] Name of variable */
- const dmn_cmn_sct * const dmn_cmn, /* I [sct] Dimension structure in output file */
- const int nbr_dmn) /* I [nbr] Number of dimensions in output file (size of above array) */
+ const char * const var_nm,  /* I [sng] Name of variable */
+ const dmn_cmn_sct * const dmn_cmn) /* I [sct] Dimension structure in output file */
 {
   /* Purpose: Use chunking map and policy to determine chunksize list
      Adapted from nco_cnk_sz_set() to GTT:
-     1) Instead of a loop for all variables, this functions chunks one variable, the object parameter variable
-     2) In the dimension loop, the dimension object is obtained from variable object...much simpler */
+     1) Instead of loop for all variables, this functions chunks one variable
+     2) In dimension loop, dimension object is obtained from variable object */
 
   const char fnc_nm[]="nco_cnk_sz_set_trv()"; /* [sng] Function name */
 
-  char var_nm[NC_MAX_NAME+1L]; /* [sng] Variable name */
-  char dmn_nm[NC_MAX_NAME];    /* [sng] Dimension name  */
-
   cnk_dmn_sct **cnk_dmn;
 
   int chk_typ; /* [enm] Checksum type */
@@ -775,6 +774,7 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
   int dmn_idx; /* [idx] Dimension index */
   int dmn_nbr; /* [nbr] Number of dimensions for variable */
   int fl_fmt; /* [enm] Input file format */
+  int shuffle; /* [enm] Shuffle filter is on */
   int srg_typ; /* [enm] Storage type */
   int var_id_in; /* [ID] Variable ID in input file */
   int var_id_out; /* [ID] Variable ID in output file */
@@ -784,11 +784,12 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
 
   nco_bool flg_usr_rqs; /* [flg] User requested checking */
   nco_bool is_rec_var; /* [flg] Record variable */
-  nco_bool is_chk_var; /* [flg] Checksummed variable */
+  nco_bool is_chk_var; /* [flg] Check-summed variable */
   nco_bool is_cmp_var; /* [flg] Compressed variable */
   nco_bool is_chunked; /* [flg] Chunked variable */
   nco_bool is_xpl_cnk; /* [flg] Explicitly chunked variable */
   nco_bool must_be_chunked; /* [flg] Variable must be chunked */
+  nco_bool flg_mch[NC_MAX_VAR_DIMS]; /* [flg] Name match (absolute or relative) between chunking structure 'cnk_sct' and dimension 'dmn_cmn' */
 
   size_t *cnk_sz=NULL; /* [nbr] Chunksize list */
   size_t cnk_sz_dfl; /* [nbr] Chunksize default */
@@ -799,8 +800,6 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
 
   unsigned long long cnk_sz_byt; /* [B] Desired bytes per chunk (e.g., system blocksize) */
 
-  long dmn_sz; /* [nbr] Size of dimension */  
-
   /* Initialize local convenience variables */
   flg_usr_rqs=cnk->flg_usr_rqs;
   cnk_nbr=cnk->cnk_nbr;
@@ -810,7 +809,7 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
   cnk_sz_byt=cnk->cnk_sz_byt;
   cnk_dmn=cnk->cnk_dmn;
 
-  /* For now only use this routine when user explicitly sets a chunking option */
+  /* Only use NCO chunking when user explicitly sets a chunking option */
   if(!flg_usr_rqs) return;
 
   /* Bail on unsupported options */
@@ -834,12 +833,13 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
 
   if(FIRST_CALL && nco_dbg_lvl_get() >= nco_dbg_fl && nco_dbg_lvl_get() != nco_dbg_dev){
     (void)fprintf(stdout,"%s: INFO User requested chunking or unchunking\n",nco_prg_nm_get());
-    if(nco_dbg_lvl_get() >= nco_dbg_scl && nco_dbg_lvl_get() != nco_dbg_dev){
+    if(nco_dbg_lvl_get() >= nco_dbg_scl  && nco_dbg_lvl_get() != nco_dbg_dev){
       (void)fprintf(stdout,"cnk_plc, cnk_map: %s, %s\n",nco_cnk_plc_sng_get(cnk_plc),nco_cnk_map_sng_get(cnk_map));
       (void)fprintf(stdout,"cnk_sz_scl, cnk_sz_byt: %lu, %lu\n",(unsigned long)cnk_sz_scl,(unsigned long)cnk_sz_byt);
       if(cnk_nbr > 0){
-	(void)fprintf(stdout,"idx dmn_nm\tcnk_sz:\n");
-	for(cnk_idx=0;cnk_idx<cnk_nbr;cnk_idx++) (void)fprintf(stdout,"%2d %s\t%lu\n",cnk_idx,cnk_dmn[cnk_idx]->nm,(unsigned long)cnk_dmn[cnk_idx]->sz);
+        (void)fprintf(stdout,"idx dmn_nm\tcnk_sz:\n");
+        for(cnk_idx=0;cnk_idx<cnk_nbr;cnk_idx++)
+	  (void)fprintf(stdout,"%2d %s\t%lu\n",cnk_idx,cnk_dmn[cnk_idx]->nm,(unsigned long)cnk_dmn[cnk_idx]->sz);
       } /* cnk_nbr == 0 */
     } /* endif dbg */
   } /* endif dbg */
@@ -848,30 +848,19 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
   /* Initialize storage type for this variable */
   srg_typ=NC_CONTIGUOUS; /* [enm] Storage type */
   is_rec_var=False; /* [flg] Record variable */
-  is_chk_var=False; /* [flg] Checksummed variable */
+  is_chk_var=False; /* [flg] Check-summed variable */
   is_cmp_var=False; /* [flg] Compressed variable */
   is_chunked=False; /* [flg] Chunked variable */
   is_xpl_cnk=False; /* [flg] Explicitly chunked variable */
 
   /* Obtain variable ID using group ID */
-  (void)nco_inq_varid(grp_id_out,nm_var,&var_id_out);
-  (void)nco_inq_varid(grp_id_in,nm_var,&var_id_in);
+  (void)nco_inq_varid(grp_id_out,var_nm,&var_id_out);
+  (void)nco_inq_varid(grp_id_in,var_nm,&var_id_in);
 
   /* Get type and number of dimensions for variable */
-  (void)nco_inq_var(grp_id_out,var_id_out,var_nm,&var_typ_dsk,&dmn_nbr,var_dimid,(int *)NULL);
+  (void)nco_inq_var(grp_id_out,var_id_out,(char *)NULL,&var_typ_dsk,&dmn_nbr,var_dimid,(int *)NULL);
   typ_sz=nco_typ_lng(var_typ_dsk);
 
-  /* Sanity check (the number of dimensions in parameter is redundant, since we are obtaining it)  */
-  assert(strcmp(var_nm,nm_var) == 0);
-  assert(nbr_dmn == dmn_nbr);
-  /* Sanity check */
-  /* Loop dimensions */
-  for(int idx_dmn=0;idx_dmn<nbr_dmn;idx_dmn++){
-    (void)nco_inq_dim(grp_id_out,var_dimid[idx_dmn],dmn_nm,&dmn_sz);
-    /* Match names of parameter array with API */
-    assert(strcmp(dmn_nm,dmn_cmn[idx_dmn].nm) == 0);
-  } /* Loop dimensions */
-
   if(dmn_nbr == 0){
     if(nco_dbg_lvl_get() == nco_dbg_old) (void)fprintf(stdout,"%s: INFO %s skipping scalar...\n",nco_prg_nm_get(),fnc_nm);
     return; 
@@ -882,10 +871,10 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
     if(dmn_cmn[dmn_idx].is_rec_dmn) is_rec_var=True;
 
   /* Is variable compressed? */
-  (void)nco_inq_var_deflate(grp_id_out,var_id_out,(int *)NULL,&deflate,(int *)NULL);
+  (void)nco_inq_var_deflate(grp_id_out,var_id_out,&shuffle,&deflate,(int *)NULL);
   if(deflate) is_cmp_var=True; 
 
-  /* Is variable checksummed? */
+  /* Is variable check-summed? */
   (void)nco_inq_var_fletcher32(grp_id_out,var_id_out,&chk_typ);
   if(chk_typ != NC_NOCHECKSUM) is_chk_var=True;
 
@@ -895,18 +884,22 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
   /* Is variable currently chunked? */
   if(nco_fmt_xtn_get() != nco_fmt_xtn_hdf4) is_chunked=nco_cnk_dsk_inq(grp_id_in,var_id_in);
 
-  /* Check if this variable has user-chunked dimensions */
+  /* Does this variable have any user-chunked dimensions? */
   if(cnk_plc == nco_cnk_plc_xpl){
     for(dmn_idx=0;dmn_idx<dmn_nbr;dmn_idx++)
-      for(cnk_idx=0;cnk_idx<cnk_nbr;cnk_idx++)
-        if(!strcmp(cnk_dmn[cnk_idx]->nm_fll,dmn_cmn[dmn_idx].nm_fll)) break;
-    /* Are one or more explicitly chunked dimensions in this variable */
+      for(cnk_idx=0;cnk_idx<cnk_nbr;cnk_idx++){
+        if(cnk_dmn[cnk_idx]->nm_fll){
+          if(!strcmp(cnk_dmn[cnk_idx]->nm_fll,dmn_cmn[dmn_idx].nm_fll)) break;
+        }else{
+          if(!strcmp(cnk_dmn[cnk_idx]->nm,dmn_cmn[dmn_idx].nm)) break;
+        } /* end else */
+      } /* end loop over cnk_idx */
     if(dmn_idx != dmn_nbr) is_xpl_cnk=True;
   } /* end plc_xpl */
 
   if(must_be_chunked){
     /* Some variables simply must be chunked */
-    if(nco_dbg_lvl_get() >= nco_dbg_var && nco_dbg_lvl_get() != nco_dbg_dev) (void)fprintf(stdout,"%s: INFO %s %s must be chunked (record, compressed, or checksummed variable)\n",nco_prg_nm_get(),fnc_nm,var_nm);
+    if(nco_dbg_lvl_get() >= nco_dbg_var && nco_dbg_lvl_get() != nco_dbg_dev) (void)fprintf(stdout,"%s: INFO %s %s must be chunked (record, compressed, or check-summed variable)\n",nco_prg_nm_get(),fnc_nm,var_nm);
   }else{
     /* Explicitly turn-off chunking for arrays that are... */
     if((cnk_plc == nco_cnk_plc_xpl && !is_xpl_cnk) || /* ...not explicitly chunked... */
@@ -919,6 +912,7 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
       if(is_chunked){
 	/* Turn-off chunking for this variable */
 	if(nco_dbg_lvl_get() >= nco_dbg_var && nco_dbg_lvl_get() != nco_dbg_dev) (void)fprintf(stdout,"%s: INFO %s unchunking %s\n",nco_prg_nm_get(),fnc_nm,var_nm);
+	if(shuffle) (void)fprintf(stdout,"%s: WARNING %s reports variable %s has shuffle flag set before unchunking. Expect the worst.",nco_prg_nm_get(),fnc_nm,var_nm);
 	(void)nco_def_var_chunking(grp_id_out,var_id_out,srg_typ,cnk_sz);
       }else{ /* !chunked */
 	if(nco_dbg_lvl_get() >= nco_dbg_var && nco_dbg_lvl_get() != nco_dbg_dev) (void)fprintf(stdout,"%s: INFO %s not unchunking %s because it is not chunked\n",nco_prg_nm_get(),fnc_nm,var_nm);
@@ -966,7 +960,7 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
       if(cnk_map == nco_cnk_map_rd1){
         cnk_sz[dmn_idx]=1UL;
         /* Record chunksize has beeen set and may still be over-ridden by explicitly specified record chunksize */
-	continue;
+        continue;
       } /* !nco_cnk_map_rd1 */
       /* Record dimension size in output file is zero until first write
 	 Obtain record dimension size from lmt_all structure (for nco_cnk_sz_set()) */
@@ -1018,12 +1012,60 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
     goto cnk_xpl_override;
   } /* !nco_cnk_map_lfp */
 
+  if(cnk_map == nco_cnk_map_rew){
+    /* Described by Russ Rew at http://www.unidata.ucar.edu/staff/russ/public/chunk_shape_3D.py
+       ncks -O -C -4 -D 6 -v four_dmn_rec_var --cnk_map=rew -p ~/nco/data in.nc ~/foo.nc */
+    double cnk_val_nbr;
+    double dmn_sz_prd=1.0; /* [nbr] Number of elements in output variable */
+    double cnk_nbr_xct; /* [nbr] Exact number of ideal chunks needed to store variable */
+    double cnk_nbr_2D_axs; /* [nbr] Exact number of ideal chunks along each 2D axis */
+    double fct_ncr=1.0; /* [frc] Factor by which to increase chunk size */
+    size_t *var_shp; /* [nbr] Shape of variable */
+
+    /* Allocate space to hold variable shape */
+    var_shp=(size_t *)nco_malloc(dmn_nbr*sizeof(size_t));    
+
+    cnk_val_nbr=cnk_sz_byt/(double)typ_sz;
+    for(dmn_idx=0;dmn_idx<=dmn_nbr-1;dmn_idx++){
+      /* Store shape for future use */
+      /* 20140131: fxm this gets wrong value for input record dimension size unless hyperslabbed. Why? */
+      if(dmn_cmn[dmn_idx].is_rec_dmn) var_shp[dmn_idx]= (dmn_cmn[dmn_idx].BASIC_DMN) ? dmn_cmn[dmn_idx].dmn_cnt : dmn_cmn[dmn_idx].sz; else var_shp[dmn_idx]= (dmn_cmn[dmn_idx].BASIC_DMN) ? dmn_cmn[dmn_idx].sz : dmn_cmn[dmn_idx].dmn_cnt;
+      assert(var_shp[dmn_idx] > 0L);
+      /* Determine hyperslab size */
+      dmn_sz_prd*=var_shp[dmn_idx];
+    } /* end loop over dmn_idx */
+    
+    cnk_nbr_xct=dmn_sz_prd/cnk_val_nbr;
+    cnk_nbr_2D_axs=pow(cnk_nbr_xct,0.25);
+
+    if(var_shp[0]/(cnk_nbr_2D_axs*cnk_nbr_2D_axs) < 1.0){
+      cnk_sz[0]=1L;
+      cnk_nbr_2D_axs=1.0/sqrt((double)var_shp[0]);
+    }else{
+      cnk_sz[0]=var_shp[0]/(cnk_nbr_2D_axs*cnk_nbr_2D_axs);
+    } /* endif */
+
+    for(dmn_idx=1;dmn_idx<=dmn_nbr-1;dmn_idx++) /* NB: Start at 1 */
+      if(var_shp[dmn_idx]/cnk_nbr_2D_axs < 1.0) fct_ncr*=cnk_nbr_2D_axs/var_shp[dmn_idx];
+    for(dmn_idx=1;dmn_idx<=dmn_nbr-1;dmn_idx++) /* NB: Start at 1 */
+      if(var_shp[dmn_idx]/cnk_nbr_2D_axs < 1.0) cnk_sz[dmn_idx]=1L; else cnk_sz[dmn_idx]=fct_ncr*var_shp[dmn_idx]/cnk_nbr_2D_axs;
+
+    if(nco_dbg_lvl_get() >= nco_dbg_var){
+      (void)fprintf(stdout,"map rew debugging:\n");
+      (void)fprintf(stdout,"cnk_nbr_xct = %g, cnk_val_nbr = %g, dmn_sz_prd = %g\n",cnk_nbr_xct,cnk_val_nbr,dmn_sz_prd);
+      (void)fprintf(stdout,"idx dmn_nm\tdmn_sz\tvar_shp\tcnk_sz:\n");
+      for(dmn_idx=0;dmn_idx<dmn_nbr;dmn_idx++) (void)fprintf(stdout,"%2d %s\t\t%lu\t%lu\t%lu\n",dmn_idx,dmn_cmn[dmn_idx].nm,(unsigned long)dmn_cmn[dmn_idx].sz,(unsigned long)var_shp[dmn_idx],(unsigned long)cnk_sz[dmn_idx]);
+    } /* endif dbg */
+
+    /* Free shape space */
+    if(var_shp) var_shp=(size_t *)nco_free(var_shp);    
+  } /* !nco_cnk_map_rew */
+
   /* Override "reasonable" defaults with explicitly set uniform scalar chunksize, if any */
   if(cnk_sz_dfl > 0UL){
     for(dmn_idx=0;dmn_idx<dmn_nbr;dmn_idx++){
       /* Is this a record dimension? */
       if(dmn_cmn[dmn_idx].is_rec_dmn){
-        /* NOTE: <GTT> Here using dimension object... much simpler */ 
         if(dmn_cmn[dmn_idx].BASIC_DMN){
           /* When not hyperslabbed, use input record dimension size ... */
           cnk_sz[dmn_idx]=(cnk_sz_dfl <= (size_t)dmn_cmn[dmn_idx].sz) ? cnk_sz_dfl : (size_t)dmn_cmn[dmn_idx].sz;
@@ -1033,7 +1075,8 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
         } /* !BASIC_DMN */
       }else{ /* !rec_dmn_id */
         /* Non-record sizes default to cnk_sz_dfl or to dimension size */
-        cnk_sz[dmn_idx]=(cnk_sz_dfl <= (size_t)dmn_cmn[dmn_idx].sz) ? cnk_sz_dfl : (size_t)dmn_cmn[dmn_idx].sz;
+	//        cnk_sz[dmn_idx]=(cnk_sz_dfl <= (size_t)dmn_cmn[dmn_idx].sz) ? cnk_sz_dfl : (size_t)dmn_cmn[dmn_idx].sz;
+        cnk_sz[dmn_idx]=(cnk_sz_dfl <= (size_t)dmn_cmn[dmn_idx].sz) ? cnk_sz_dfl : (size_t)dmn_cmn[dmn_idx].dmn_cnt;
       } /* !is_rec_dmn */
     } /* end loop over dimensions */
   } /* !cnk_sz_dfl */
@@ -1041,29 +1084,39 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
 cnk_xpl_override: /* end goto */
 
   /* Override "reasonable" defaults with explicitly set per-dimension sizes, if any */
-  for(cnk_idx=0;cnk_idx<cnk_nbr;cnk_idx++){
-    for(dmn_idx=0;dmn_idx<dmn_nbr;dmn_idx++){
-      /* Match on name not ID */
-      /* fxm pvn check origin of chunk names */
-      if(!strcmp(cnk_dmn[cnk_idx]->nm,dmn_cmn[dmn_idx].nm)){
+  for(dmn_idx=0;dmn_idx<dmn_nbr;dmn_idx++){
+
+    /* Initialize to false then override */
+    flg_mch[dmn_idx]=False;
+
+    for(cnk_idx=0;cnk_idx<cnk_nbr;cnk_idx++){
+
+      if(cnk_dmn[cnk_idx]->nm_fll){
+        if(!strcmp(cnk_dmn[cnk_idx]->nm_fll,dmn_cmn[dmn_idx].nm_fll)) flg_mch[dmn_idx]=True;
+      }else{
+        if(!strcmp(cnk_dmn[cnk_idx]->nm,dmn_cmn[dmn_idx].nm)) flg_mch[dmn_idx]=True;
+      } /* end else */
+
+      /* Name match found */
+      if(flg_mch[dmn_idx]){
         cnk_sz[dmn_idx]=cnk_dmn[cnk_idx]->sz;
         /* Is this a record dimension? */
         if(dmn_cmn[dmn_idx].is_rec_dmn){
-	  /* dmn_sz of record dimension may (will) be zero in output file
-	     Must allow (though warn) when cnk_sz > dmn_sz in such cases */
-	  if(dmn_cmn[dmn_idx].BASIC_DMN){
+          /* dmn_sz of record dimension can/will be zero in output file
+	     Allow (though warn) when cnk_sz > dmn_sz in such cases */
+          if(dmn_cmn[dmn_idx].BASIC_DMN){
             if(cnk_sz[dmn_idx] > (size_t)dmn_cmn[dmn_idx].sz){
               (void)fprintf(stderr,"%s: WARNING %s allowing user-specified record dimension %s chunksize %lu which exceeds current record dimension size in output file = %lu. May fail if output file is not concatenated from multiple inputs.\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_dmn[cnk_idx]->sz,(unsigned long)dmn_cmn[dmn_idx].sz);
             } /* endif too big */
           }else{ /* !BASIC_DMN */
             if(cnk_sz[dmn_idx] > (size_t)dmn_cmn[dmn_idx].dmn_cnt){
-              (void)fprintf(stderr,"%s: WARNING %s allowing user-specified record dimension %s chunksize = %lu which exceeds user-specified record dimension input hyperslab size = %lu. May fail if output file is not concatenated from multiple inputs.\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_dmn[cnk_idx]->sz,dmn_cmn[dmn_idx].dmn_cnt);
+              (void)fprintf(stderr,"%s: WARNING %s allowing user-specified record dimension %s chunksize = %lu which exceeds user-specified record dimension input hyperslab size = %lu. May fail if output file is not concatenated from multiple inputs.\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_dmn[cnk_idx]->sz,(unsigned long)dmn_cmn[dmn_idx].dmn_cnt);
             } /* endif too big */
           } /* !BASIC_DMN */
         }else{ /* !rcd_dmn_id */
           if(cnk_sz[dmn_idx] > (size_t)dmn_cmn[dmn_idx].sz){
-	    /* Unlike record dimensions, non-record dimensions must have cnk_sz <= dmn_sz */
-            (void)fprintf(stderr,"%s: WARNING %s trimming user-specified %s chunksize from %lu to %lu\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_dmn[cnk_idx]->sz,(unsigned long)dmn_cmn[dmn_idx].sz);
+            /* Unlike record dimensions, non-record dimensions must have cnk_sz <= dmn_sz */
+            (void)fprintf(stderr,"%s: WARNING %s trimming user-specified fixed dimension %s chunksize from %lu to %lu\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_dmn[cnk_idx]->sz,(unsigned long)dmn_cmn[dmn_idx].sz);
             /* Trim else out-of-bounds sizes will fail in HDF library in nc_enddef() */
             cnk_sz[dmn_idx]=(size_t)dmn_cmn[dmn_idx].sz;
           } /* endif */
@@ -1079,10 +1132,10 @@ cnk_xpl_override: /* end goto */
   for(dmn_idx=0;dmn_idx<dmn_nbr;dmn_idx++){
     if(cnk_sz[dmn_idx] > (size_t)dmn_cmn[dmn_idx].sz){
       if(!dmn_cmn[dmn_idx].is_rec_dmn){
-	/* Unlike record dimensions, non-record dimensions must have cnk_sz <= dmn_sz */
-	(void)fprintf(stderr,"%s: WARNING %s final check trimming %s chunksize from %lu to %lu\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_dmn[cnk_idx]->sz,(unsigned long)dmn_cmn[dmn_idx].sz);
-	/* Trim else out-of-bounds sizes will fail in HDF library in nc_enddef() */
-	cnk_sz[dmn_idx]=(size_t)dmn_cmn[dmn_idx].sz;
+        /* Unlike record dimensions, non-record dimensions must have cnk_sz <= dmn_sz */
+        (void)fprintf(stderr,"%s: WARNING %s final check trimming %s chunksize from %lu to %lu\n",nco_prg_nm_get(),fnc_nm,dmn_cmn[dmn_idx].nm,(unsigned long)cnk_sz[dmn_idx],(unsigned long)dmn_cmn[dmn_idx].sz);
+        /* Trim else out-of-bounds sizes will fail in HDF library in nc_enddef() */
+        cnk_sz[dmn_idx]=(size_t)dmn_cmn[dmn_idx].sz;
       } /* rcd_dmn_id */
     } /* end if */
   } /* end loop over dmn */
@@ -1093,7 +1146,7 @@ cnk_xpl_override: /* end goto */
     for(dmn_idx=0;dmn_idx<dmn_nbr;dmn_idx++) (void)fprintf(stdout,"%2d %s\t%lu\t%lu\n",dmn_idx,dmn_cmn[dmn_idx].nm_fll,(unsigned long)dmn_cmn[dmn_idx].sz,(unsigned long)cnk_sz[dmn_idx]);
   } /* endif dbg */
 
-  /* Turn-on chunking for this variable */
+  /* Set storage (chunked or contiguous) for this variable */
   (void)nco_def_var_chunking(grp_id_out,var_id_out,srg_typ,cnk_sz);
 
   /* Free space holding dimension IDs and chunksizes */
