@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_cnk.h,v 1.35 2014/01/06 22:17:01 pvicente Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_cnk.h,v 1.37 2014/02/01 02:52:30 zender Exp $ */
 
 /* Purpose: Description (definition) of chunking functions */
 
@@ -47,7 +47,8 @@ enum nco_cnk_map{ /* [enm] Chunking conversion map */
   nco_cnk_map_scl, /* 3 [enm] Chunksize equals scalar size specified */
   nco_cnk_map_prd, /* 4 [enm] Chunksize product is scalar size specified */
   nco_cnk_map_lfp, /* 5 [enm] Chunksizes of lefter dimensions flexes to matches scalar size specified */
-  nco_cnk_map_xst /* 6 [enm] Chunksize equals chunk-sizes in input file */
+  nco_cnk_map_xst, /* 6 [enm] Chunksize equals chunk-sizes in input file */
+  nco_cnk_map_rew /* 7 [enm] Chunksize balances access to 1D and 2D slabs of 3D variable */
 }; /* end nco_cnk_map enum */
 
 #ifdef __cplusplus
@@ -110,8 +111,7 @@ nco_cnk_sz_set_trv /* [fnc] Set chunksize parameters (GTT version of nco_cnk_sz_
  const int grp_id_out, /* I [id] netCDF group ID in output file */
  const cnk_sct * const cnk, /* I [sct] Chunking structure */
  const char * const var_nm,  /* I [sng] Name of variable */
- const dmn_cmn_sct * const dmn_cmn, /* I [sct] Dimension structure in output file */
- const int nbr_dmn); /* I [nbr] Number of dimensions in output file (size of above array) */
+ const dmn_cmn_sct * const dmn_cmn); /* I [sct] Dimension structure in output file */
 
 int /* O [enm] Chunking map */
 nco_cnk_map_get /* [fnc] Convert user-specified chunking map to key */
