@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_dmn_utl.c,v 1.66 2013/10/22 03:03:45 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_dmn_utl.c,v 1.68 2014/01/02 22:56:39 zender Exp $ */
 
 /* Purpose: Dimension utilities */
 
-/* Copyright (C) 1995--2013 Charlie Zender
+/* Copyright (C) 1995--2014 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -140,7 +140,7 @@ void
 nco_dmn_cnk_mrg /* [fnc] Merge chunking information into dimension structures */
 (dmn_sct ** const dmn, /* I [sct] Dimension structures to modify */
  const int nbr_dmn, /* I [nbr] Number of dimension structures in structure list */
- CST_X_PTR_CST_PTR_CST_Y(cnk_sct,cnk), /* I [sct] Chunking information */
+ CST_X_PTR_CST_PTR_CST_Y(cnk_dmn_sct,cnk_dmn), /* I [sct] Chunking information */
  const int cnk_nbr) /* I [nbr] Number of dimensions with user-specified chunking */
 {
   /* Purpose: Merge chunking information into dimension structures */
@@ -151,8 +151,8 @@ nco_dmn_cnk_mrg /* [fnc] Merge chunking information into dimension structures */
     /* Does this dimension have user-specified chunking? */
     for(cnk_idx=0;cnk_idx<cnk_nbr;cnk_idx++){
       /* Match on name not ID so nco_dmn_cnk_mrg() works on any input file */
-      if(!strcmp(cnk[cnk_idx]->nm,dmn[dmn_idx]->nm)){
-	dmn[dmn_idx]->cnk_sz=cnk[cnk_idx]->sz;
+      if(!strcmp(cnk_dmn[cnk_idx]->nm,dmn[dmn_idx]->nm)){
+	dmn[dmn_idx]->cnk_sz=cnk_dmn[cnk_idx]->sz;
 	break;
       } /* end if */
     } /* end loop over cnk_idx */
