@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_fl_utl.c,v 1.234 2014/01/06 07:46:17 pvicente Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_fl_utl.c,v 1.239 2014/02/20 18:25:45 zender Exp $ */
 
 /* Purpose: File manipulation */
 
@@ -1373,10 +1373,13 @@ nco_fl_open /* [fnc] Open file using appropriate buffer size hints and verbosity
   /* 20131222: Update underlying file-type using new nc_inq_format_extended() function */
   fl_fmt_xtn_prv=nco_fmt_xtn_get();
   rcd+=nco_inq_format_extended(*nc_id,&fl_fmt_xtn_crr,&mode);
-  /* Complain if set value of extended type does not match current type */
-  if((fl_fmt_xtn_prv != nco_fmt_xtn_nil) && (fl_fmt_xtn_prv != fl_fmt_xtn_crr)) (void)fprintf(stderr,"%s: WARNING %s reports current extended filetype = %s does not equal previous extended filetype = %s\n",nco_prg_nm_get(),fnc_nm,nco_fmt_xtn_sng(fl_fmt_xtn_crr),nco_fmt_xtn_sng(fl_fmt_xtn_prv));
-  /* If user did not set filetype manually, override it with actual filetype */
-  if(!fl_fmt_xtn_prv) nco_fmt_xtn_set(fl_fmt_xtn_crr);
+  if(fl_fmt_xtn_prv != nco_fmt_xtn_nil){
+    /* Complain if set value of extended type does not match current type */
+    if(fl_fmt_xtn_prv != fl_fmt_xtn_crr) (void)fprintf(stderr,"%s: INFO %s reports current extended filetype = %s does not equal previous extended filetype = %s. This is expected when NCO is instructed to convert filetypes, i.e., to read from one type and write to another. However, it could also indicate an unexpected change in input dataset type that the user should be cognizant of.\n",nco_prg_nm_get(),fnc_nm,nco_fmt_xtn_sng(fl_fmt_xtn_crr),nco_fmt_xtn_sng(fl_fmt_xtn_prv));
+  }else{
+    /* Set undefined extended file type to actual extended filetype */
+    nco_fmt_xtn_set(fl_fmt_xtn_crr);
+  } /* endif */
   if(nco_dbg_lvl_get() >= nco_dbg_fl) (void)fprintf(stderr,"%s: INFO Extended filetype of %s is %s, mode = %d\n",nco_prg_nm_get(),fl_nm,nco_fmt_xtn_sng(fl_fmt_xtn_crr),mode);
 
   return rcd;
@@ -1384,7 +1387,7 @@ nco_fl_open /* [fnc] Open file using appropriate buffer size hints and verbosity
 
 size_t /* [B] Blocksize */
 nco_fl_blocksize /* [fnc] Find blocksize of filesystem will or does contain this file */
-(const char const * fl_out) /* [sng] Filename */
+(const char * const fl_out) /* [sng] Filename */
 {
   /* Purpose: Find blocksize of filesystem will or does contain this file */
   const char fnc_nm[]="nco_fl_blocksize()"; /* [sng] Function name */
@@ -1543,7 +1546,7 @@ nco_fl_out_open /* [fnc] Open output file subject to availability and user input
     /* 20020812: Cray OS does not support mkstemp() */
     fl_out_hnd=creat(mktemp(fl_out_tmp_sys),0600);
 #endif /* !HAVE_MKSTEMP */
-    fl_out_hnd=fl_out_hnd; /* Removes compiler warning on SGI */
+    fl_out_hnd=fl_out_hnd+0; /* CEWI Removes compiler warning on SGI */
     if(nco_dbg_lvl_get() >= nco_dbg_scl) (void)fprintf(stdout,"%s: %s reports strlen(fl_out_tmp_sys) = %ld, fl_out_tmp_sys = %s, \n",nco_prg_nm_get(),fnc_nm,(long)strlen(fl_out_tmp_sys),fl_out_tmp_sys);
     fl_out_tmp_sys=(char *)nco_free(fl_out_tmp_sys);
   } /* endif dbg */
