@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_grp_trv.c,v 1.261 2013/12/31 05:14:01 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_grp_trv.c,v 1.274 2014/02/18 06:38:36 pvicente Exp $ */
 
 /* Purpose: netCDF4 traversal storage */
 
@@ -30,15 +30,13 @@ trv_tbl_init                           /* [fnc] GTT initialize */
   tb->nbr_dmn_dgn=0;
   tb->dmn_dgn=NULL;
 
-  /* Record dimensions used by ncra */
-  tb->nbr_rec=0;
-  tb->lmt_rec=NULL;
-
   /* Ensembles */
   tb->nsm_nbr=0;
   tb->nsm=NULL;
   tb->nsm_sfx=NULL;
 
+  tb->nsm_skp=NULL;
+
   *tbl=tb;
 } /* trv_tbl_init() */
  
@@ -51,6 +49,7 @@ trv_tbl_free                           /* [fnc] GTT free memory */
   for(unsigned idx=0;idx<tbl->nbr;idx++){
     tbl->lst[idx].nm_fll=(char *)nco_free(tbl->lst[idx].nm_fll);
     tbl->lst[idx].nm=(char *)nco_free(tbl->lst[idx].nm);
+    tbl->lst[idx].grp_nm=(char *)nco_free(tbl->lst[idx].grp_nm);
     tbl->lst[idx].grp_nm_fll=(char *)nco_free(tbl->lst[idx].grp_nm_fll);
     tbl->lst[idx].grp_nm_fll_prn=(char *)nco_free(tbl->lst[idx].grp_nm_fll_prn);
     tbl->lst[idx].nsm_nm=(char *)nco_free(tbl->lst[idx].nsm_nm);
@@ -66,6 +65,15 @@ trv_tbl_free                           /* [fnc] GTT free memory */
         tbl->lst[idx].var_dmn[dmn_idx].dmn_nm=(char *)nco_free(tbl->lst[idx].var_dmn[dmn_idx].dmn_nm);
         tbl->lst[idx].var_dmn[dmn_idx].grp_nm_fll=(char *)nco_free(tbl->lst[idx].var_dmn[dmn_idx].grp_nm_fll);
 
+        int nbr_lat_crd=tbl->lst[idx].var_dmn[dmn_idx].nbr_lat_crd;
+        for(int idx_crd=0;idx_crd<nbr_lat_crd;idx_crd++){     
+          tbl->lst[idx].var_dmn[dmn_idx].lat_crd[idx_crd].nm_fll=(char *)nco_free(tbl->lst[idx].var_dmn[dmn_idx].lat_crd[idx_crd].nm_fll); 
+        }   
+        int nbr_lon_crd=tbl->lst[idx].var_dmn[dmn_idx].nbr_lon_crd;
+        for(int idx_crd=0;idx_crd<nbr_lon_crd;idx_crd++){     
+          tbl->lst[idx].var_dmn[dmn_idx].lon_crd[idx_crd].nm_fll=(char *)nco_free(tbl->lst[idx].var_dmn[dmn_idx].lon_crd[idx_crd].nm_fll); 
+        }    
+
         /* Coordinate structure */ 
         if(tbl->lst[idx].var_dmn[dmn_idx].crd){
           tbl->lst[idx].var_dmn[dmn_idx].crd->crd_nm_fll=(char *)nco_free(tbl->lst[idx].var_dmn[dmn_idx].crd->crd_nm_fll);
@@ -129,10 +137,6 @@ trv_tbl_free                           /* [fnc] GTT free memory */
 
   /* Members used only by transformation operators (non-ncks) */
 
-  /* (ncra) Record dimensions */
-  for(int idx=0;idx<tbl->nbr_rec;idx++)
-    tbl->lmt_rec[idx]=nco_lmt_free(tbl->lmt_rec[idx]);
-
   /* (ncwa) Degenerate dimensions */
   tbl->dmn_dgn=(dmn_sct *)nco_free(tbl->dmn_dgn); 
 
@@ -153,6 +157,12 @@ trv_tbl_free                           /* [fnc] GTT free memory */
 
   tbl->nsm_sfx=(char *)nco_free(tbl->nsm_sfx);  
 
+  if(tbl->nsm_skp){
+    for(int idx=0;idx<tbl->nsm_skp->nbr;idx++){
+      tbl->nsm_skp->lst[idx].nm=(char *)nco_free(tbl->nsm_skp->lst[idx].nm);
+    }
+  }
+
   tbl=(trv_tbl_sct *)nco_free(tbl);
 } /* end trv_tbl_free() */
 
@@ -233,13 +243,15 @@ trv_tbl_prn_flg_mch                  /* [fnc] Print table items that have .flg_m
 
 void 
 trv_tbl_prn_flg_xtr                  /* [fnc] Print table items that have .flg_xtr  */
-(const trv_tbl_sct * const trv_tbl)  /* I [sct] Traversal table */
+(const char * const fnc_nm,          /* I [sng] Function name  */
+ const trv_tbl_sct * const trv_tbl)  /* I [sct] Traversal table */
 {
+  (void)fprintf(stdout,"%s: INFO %s reports extracted objects:\n",nco_prg_nm_get(),fnc_nm);
  /* Print all matching objects from traversal table */
   trv_sct trv_obj;
   for(unsigned int tbl_idx=0;tbl_idx<trv_tbl->nbr;tbl_idx++){
     trv_obj=trv_tbl->lst[tbl_idx];
-    if(trv_obj.flg_xtr) (void)fprintf(stdout,"nm_fll=%s\n",trv_obj.nm_fll);
+    if(trv_obj.flg_xtr) (void)fprintf(stdout,"%s\n",trv_obj.nm_fll);
   } /* end loop over trv_tbl */
 } /* end trv_tbl_prn_flg_xtr() */
 
@@ -277,7 +289,6 @@ trv_tbl_var_nm_fll                    /* [fnc] Return variable object from full
   trv_sct *trv_obj; /* [sct] GTT object structure */
   HASH_FIND_STR(trv_tbl->hsh,var_nm_fll,trv_obj);
   if(trv_obj && trv_obj->nco_typ == nco_obj_typ_var) return trv_obj; else return NULL;
-  //  return trv_obj;
 #else /* !NCO_HSH_TRV_OBJ */
   for(unsigned uidx=0;uidx<trv_tbl->nbr;uidx++)
     if(trv_tbl->lst[uidx].nco_typ == nco_obj_typ_var && !strcmp(var_nm_fll,trv_tbl->lst[uidx].nm_fll)) return &trv_tbl->lst[uidx];
@@ -287,19 +298,37 @@ trv_tbl_var_nm_fll                    /* [fnc] Return variable object from full
 
 } /* trv_tbl_var_nm_fll() */
 
+trv_sct *                             /* O [sct] Table object */
+trv_tbl_grp_nm_fll                    /* [fnc] Return group object from full name key */
+(const char * const grp_nm_fll,       /* I [sng] Group name to find */
+ const trv_tbl_sct * const trv_tbl)   /* I [sct] Traversal table */
+{
+  /* Purpose: Return group object with given full name */
+
+  for(unsigned uidx=0;uidx<trv_tbl->nbr;uidx++){
+    if(trv_tbl->lst[uidx].nco_typ == nco_obj_typ_grp && 
+      strcmp(grp_nm_fll,trv_tbl->lst[uidx].nm_fll) == 0){
+      return &trv_tbl->lst[uidx];
+    }
+  }
+
+  return NULL;
+} /* trv_tbl_grp_nm_fll() */
+
 void
 trv_tbl_mrk_xtr                       /* [fnc] Mark extraction flag in table for "var_nm_fll" */
 (const char * const var_nm_fll,       /* I [sng] Variable name to find */
+ const nco_bool flg_xtr,              /* I [flg] Flag (True or False) */
  trv_tbl_sct * const trv_tbl)         /* I/O [sct] Traversal table */
 {
 
 #ifdef NCO_HSH_TRV_OBJ
   trv_sct *trv_obj; /* [sct] GTT object structure */
   HASH_FIND_STR(trv_tbl->hsh,var_nm_fll,trv_obj);
-  if(trv_obj) trv_obj->flg_xtr=True;
+  if(trv_obj) trv_obj->flg_xtr=flg_xtr;
 #else /* !NCO_HSH_TRV_OBJ */
   for(unsigned uidx=0;uidx<trv_tbl->nbr;uidx++)
-    if(!strcmp(var_nm_fll,trv_tbl->lst[uidx].nm_fll)) trv_tbl->lst[uidx].flg_xtr=True;
+    if(!strcmp(var_nm_fll,trv_tbl->lst[uidx].nm_fll)) trv_tbl->lst[uidx].flg_xtr=flg_xtr;
 #endif /* !NCO_HSH_TRV_OBJ */
 
   return;
@@ -430,7 +459,7 @@ trv_tbl_mch                            /* [fnc] Match 2 tables (find common obje
     if(!nco_cmp){
       (*cmn_lst)[idx_lst].flg_in_fl[0]=True;
       (*cmn_lst)[idx_lst].flg_in_fl[1]=True;
-      (*cmn_lst)[idx_lst].var_nm_fll=strdup(trv_1.nm_fll);
+      (*cmn_lst)[idx_lst].nm=strdup(trv_1.nm_fll);
       idx_lst++;
 
       idx_tbl_1++;
@@ -440,7 +469,7 @@ trv_tbl_mch                            /* [fnc] Match 2 tables (find common obje
 
       (*cmn_lst)[idx_lst].flg_in_fl[0]=True;
       (*cmn_lst)[idx_lst].flg_in_fl[1]=False;
-      (*cmn_lst)[idx_lst].var_nm_fll=strdup(trv_1.nm_fll);
+      (*cmn_lst)[idx_lst].nm=strdup(trv_1.nm_fll);
       idx_lst++;
 
       if(nco_dbg_lvl_get() == nco_dbg_old)(void)fprintf(stdout,"%s: INFO %s reports tbl_1[%d]:%s\n",nco_prg_nm_get(),fnc_nm,idx_tbl_1,trv_1.nm_fll);
@@ -449,7 +478,7 @@ trv_tbl_mch                            /* [fnc] Match 2 tables (find common obje
       /* Name(1) is greater than Name(2), read next name from List 2 */
       (*cmn_lst)[idx_lst].flg_in_fl[0]=False;
       (*cmn_lst)[idx_lst].flg_in_fl[1]=True;
-      (*cmn_lst)[idx_lst].var_nm_fll=strdup(trv_2.nm_fll);
+      (*cmn_lst)[idx_lst].nm=strdup(trv_2.nm_fll);
       idx_lst++;
 
       if(nco_dbg_lvl_get() == nco_dbg_old)(void)fprintf(stdout,"%s: INFO %s reports tbl_2[%d]:%s\n",nco_prg_nm_get(),fnc_nm,idx_tbl_2,trv_2.nm_fll);
@@ -466,7 +495,7 @@ trv_tbl_mch                            /* [fnc] Match 2 tables (find common obje
     while(idx_tbl_1 < nbr_tbl_1){
       (*cmn_lst)[idx_lst].flg_in_fl[0]=True;
       (*cmn_lst)[idx_lst].flg_in_fl[1]=False;
-      (*cmn_lst)[idx_lst].var_nm_fll=strdup(trv_tbl_1->lst[idx_tbl_1].nm_fll);
+      (*cmn_lst)[idx_lst].nm=strdup(trv_tbl_1->lst[idx_tbl_1].nm_fll);
       idx_lst++;
 
       if(nco_dbg_lvl_get() == nco_dbg_old) (void)fprintf(stdout,"%s: INFO %s reports tbl_1[%d]:%s\n",nco_prg_nm_get(),fnc_nm,idx_tbl_1,trv_tbl_1->lst[idx_tbl_1].nm_fll);
@@ -479,7 +508,7 @@ trv_tbl_mch                            /* [fnc] Match 2 tables (find common obje
     while(idx_tbl_2 < nbr_tbl_2){
       (*cmn_lst)[idx_lst].flg_in_fl[0]=False;
       (*cmn_lst)[idx_lst].flg_in_fl[1]=True;
-      (*cmn_lst)[idx_lst].var_nm_fll=strdup(trv_tbl_2->lst[idx_tbl_2].nm_fll);
+      (*cmn_lst)[idx_lst].nm=strdup(trv_tbl_2->lst[idx_tbl_2].nm_fll);
       idx_lst++;
 
       if(nco_dbg_lvl_get() == nco_dbg_old)(void)fprintf(stdout,"%s: INFO %s reports tbl_2[%d]:%s\n",nco_prg_nm_get(),fnc_nm,idx_tbl_2,trv_tbl_2->lst[idx_tbl_2].nm_fll);
@@ -506,7 +535,7 @@ trv_tbl_cmn_nm_prt                         /* [fnc] Print list of common objects
     char c1, c2;
     c1 = (cmn_lst[idx].flg_in_fl[0]) ? 'x' : ' ';
     c2 = (cmn_lst[idx].flg_in_fl[1]) ? 'x' : ' ';
-    (void)fprintf(stdout,"%5c %6c    %-15s\n", c1, c2, cmn_lst[idx].var_nm_fll);
+    (void)fprintf(stdout,"%5c %6c    %-15s\n", c1, c2, cmn_lst[idx].nm);
   } /* end loop over idx */
   (void)fprintf(stdout,"\n");
 
@@ -554,20 +583,6 @@ nco_dmn_set_msa                       /* [fnc] Update dimension with hyperslabbe
   return;
 } /* nco_dmn_set_msa() */
 
-long                                  /* O [nbr] Hyperslabbed size */
-nco_dmn_get_msa                       /* [fnc] Update dimension with hyperslabbed size */
-(const int dmn_id,                    /* I [id] Unique dimension ID */
- const trv_tbl_sct * const trv_tbl)   /* I [sct] GTT (Group Traversal Table) */
-{
-  /* Search table dimension list and compare IDs */
-  for(unsigned int dmn_idx=0;dmn_idx<trv_tbl->nbr_dmn;dmn_idx++)
-    if(dmn_id == trv_tbl->lst_dmn[dmn_idx].dmn_id)
-      return trv_tbl->lst_dmn[dmn_idx].lmt_msa.dmn_cnt;
-     
-  assert(0);
-  return -1;
-} /* nco_dmn_get_msa() */
-
 void
 nco_trv_hsh_del /* Delete hash table */
 (trv_tbl_sct * const trv_tbl) /* I/O [sct] Traversal table */
@@ -732,7 +747,7 @@ nco_nm_mch                             /* [fnc] Match 2 lists of strings and mar
     if(!nco_cmp){
       (*cmn_lst)[idx_lst].flg_in_fl[0]=True;
       (*cmn_lst)[idx_lst].flg_in_fl[1]=True;
-      (*cmn_lst)[idx_lst].var_nm_fll=strdup(nm_1);
+      (*cmn_lst)[idx_lst].nm=strdup(nm_1);
       idx_lst++;
       idx_tbl_1++;
       idx_tbl_2++;
@@ -742,14 +757,14 @@ nco_nm_mch                             /* [fnc] Match 2 lists of strings and mar
       /* Name(1) is less than Name(2), read next name from List 1  */
       (*cmn_lst)[idx_lst].flg_in_fl[0]=True;
       (*cmn_lst)[idx_lst].flg_in_fl[1]=False;
-      (*cmn_lst)[idx_lst].var_nm_fll=strdup(nm_1);
+      (*cmn_lst)[idx_lst].nm=strdup(nm_1);
       idx_lst++; 
       idx_tbl_1++;
     }else{
       /* Name(1) is greater than Name(2), read next name from List 2 */
       (*cmn_lst)[idx_lst].flg_in_fl[0]=False;
       (*cmn_lst)[idx_lst].flg_in_fl[1]=True;
-      (*cmn_lst)[idx_lst].var_nm_fll=strdup(nm_2);
+      (*cmn_lst)[idx_lst].nm=strdup(nm_2);
       idx_lst++;   
       idx_tbl_2++;
     } /* end nco_cmp */
@@ -764,7 +779,7 @@ nco_nm_mch                             /* [fnc] Match 2 lists of strings and mar
     while(idx_tbl_1 < nbr_tbl_1){
       (*cmn_lst)[idx_lst].flg_in_fl[0]=True;
       (*cmn_lst)[idx_lst].flg_in_fl[1]=False;
-      (*cmn_lst)[idx_lst].var_nm_fll=strdup(nm_lst_1[idx_tbl_1]);
+      (*cmn_lst)[idx_lst].nm=strdup(nm_lst_1[idx_tbl_1]);
       idx_lst++;
       idx_tbl_1++;
     } /* end while */
@@ -775,7 +790,7 @@ nco_nm_mch                             /* [fnc] Match 2 lists of strings and mar
     while(idx_tbl_2 < nbr_tbl_2){
       (*cmn_lst)[idx_lst].flg_in_fl[0]=False;
       (*cmn_lst)[idx_lst].flg_in_fl[1]=True;
-      (*cmn_lst)[idx_lst].var_nm_fll=strdup(nm_lst_2[idx_tbl_2]);
+      (*cmn_lst)[idx_lst].nm=strdup(nm_lst_2[idx_tbl_2]);
       idx_lst++;
       idx_tbl_2++;
     } /* end while */
@@ -832,7 +847,7 @@ nco_lst_ins                            /* [fnc] Utility function to detect inser
   /* Loop constructed array to see if already inserted */
   for(int idx_nm=0;idx_nm<nbr_nm;idx_nm++){
       /* Match */
-      if(strcmp(cmn_lst[idx_nm].var_nm_fll,nm) == 0){
+      if(strcmp(cmn_lst[idx_nm].nm,nm) == 0){
         /* Mark as inserted in array */
         return True;
       }  /* Match */
@@ -871,3 +886,32 @@ nco_bld_nsm_sfx                        /* [fnc] Build ensemble suffix */
   return NULL;
 
 } /* nco_bld_nsm_sfx() */
+
+nco_bool                              
+nco_is_fll_pth                         /* [fnc] Utility function to inquire if a string is a full path */
+(const char * const str)               /* I [sng] A string to inquire */
+{
+  const char *sbs_srt; /* [sng] Location of string match start in parameter string */
+
+  /* If parameter string contains any slash character '/' , assume it's a full path */
+  sbs_srt=strstr(str,"/");
+  if (sbs_srt) return True;
+  return False;
+
+} /* nco_is_fll_pth() */
+
+
+char *
+nco_strrstr                            /* [fnc] Searches a substring starting from the end */
+(const char *str,                      /* [fnc] String */
+ const char *str_fnd)                  /* [fnc] String to find */
+{
+  char *ptr;
+  char *lst=NULL;
+
+  ptr = (char*)str;
+  while((ptr = strstr(ptr, str_fnd))){
+    lst = ptr++;
+  }
+  return lst;
+} /* nco_strrstr() */
