@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_grp_trv.h,v 1.107 2013/12/31 05:14:01 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_grp_trv.h,v 1.113 2014/02/15 20:21:08 pvicente Exp $ */
 
 /* Purpose: netCDF4 traversal storage */
 
@@ -69,9 +69,15 @@ trv_tbl_var_nm_fll                     /* [fnc] Return object from full name key
 (const char * const var_nm_fll,        /* I [sng] Variable name to find */
  const trv_tbl_sct * const trv_tbl);   /* I [sct] Traversal table */
 
+trv_sct *                              /* O [sct] Table object */
+trv_tbl_grp_nm_fll                     /* [fnc] Return group object from full name key */
+(const char * const grp_nm_fll,        /* I [sng] Group name to find */
+ const trv_tbl_sct * const trv_tbl);   /* I [sct] Traversal table */
+
 void
 trv_tbl_mrk_xtr                        /* [fnc] Mark extraction flag in table for "var_nm_fll" */
 (const char * const var_nm_fll,        /* I [sng] Variable name to find */
+ const nco_bool flg_xtr,               /* I [flg] Flag (True or False) */
  trv_tbl_sct * const trv_tbl);         /* I/O [sct] Traversal table */
 
 void
@@ -101,8 +107,9 @@ trv_tbl_mch                            /* [fnc] Match 2 tables (find common obje
  int * nbr_cmn_nm);                    /* I/O [nbr] Number of common names entries */
 
 void 
-trv_tbl_prn_flg_xtr                    /* [fnc] Print table items that have .flg_xtr  */
-(const trv_tbl_sct * const trv_tbl);   /* I [sct] Traversal table */
+trv_tbl_prn_flg_xtr                   /* [fnc] Print table items that have .flg_xtr  */
+(const char * const fnc_nm,           /* I [sng] Function name  */
+ const trv_tbl_sct * const trv_tbl);  /* I [sct] Traversal table */
 
 void                          
 trv_tbl_cmn_nm_prt                     /* [fnc] Print list of common objects (same absolute path) */
@@ -120,11 +127,6 @@ nco_dmn_set_msa                       /* [fnc] Update dimension with hyperslabbe
  const long dmn_cnt,                  /* I [nbr] New dimension size */
  trv_tbl_sct * const trv_tbl);        /* I/O [sct] GTT (Group Traversal Table) */
 
-long                                  /* O hyperslabbed size */
-nco_dmn_get_msa                       /* [fnc] Update dimension with hyperslabbed size */
-(const int dmn_id,                    /* I [id] Unique dimension ID */
- const trv_tbl_sct * const trv_tbl);  /* I [sct] GTT (Group Traversal Table) */
-
 void 
 nco_trv_hsh_bld                       /* Hash traversal table for fastest access */
 (trv_tbl_sct * const trv_tbl);        /* I/O [sct] Traversal table */
@@ -171,5 +173,14 @@ nco_bld_nsm_sfx                        /* [fnc] Build ensemble suffix */
 (const char * const grp_nm_fll_prn,    /* I [sng] Absolute group name of ensemble root */
  const trv_tbl_sct * const trv_tbl);   /* I [sct] Traversal table */
 
+nco_bool                              
+nco_is_fll_pth                         /* [fnc] Utility function to inquire if a string is a full path */
+(const char * const str);              /* I [sng] A string to inquire */
+
+char *
+nco_strrstr                            /* [fnc] Searches a substring starting from the end */
+(const char *str,                      /* [fnc] String */
+ const char *str_fnd);                 /* [fnc] String to find */
+
 
 #endif /* NCO_GRP_TRV_H */
