@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_grp_utl.h,v 1.435 2014/01/07 21:42:39 pvicente Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_grp_utl.h,v 1.461 2014/02/19 21:36:44 pvicente Exp $ */
 
 /* Purpose: Group utilities */
 
@@ -307,14 +307,14 @@ nco_get_rec_dmn_nm                     /* [fnc] Return array of record names  */
  nm_tbl_sct ** rec_dmn_nm);            /* I/O [sct] Array of record names */
  
 void
-nco_bld_aux_crd                       /* [fnc] Parse auxiliary coordinates */
+nco_prs_aux_crd                       /* [fnc] Parse auxiliary coordinates */
 (const int nc_id,                     /* I [ID] netCDF file ID */
  const int aux_nbr,                   /* I [nbr] Number of auxiliary coordinates */
  char *aux_arg[],                     /* I [sng] Auxiliary coordinates */
- int *lmt_nbr,                        /* I/O [nbr] Number of user-specified dimension limits */
- lmt_sct ***lmt,                      /* I/O [sct] Limit structure  */
- const nco_bool EXTRACT_ASSOCIATED_COORDINATES,  /* I [flg] Extract all coordinates associated with extracted variables? */ 
- const trv_tbl_sct * const trv_tbl);  /* I [sct] GTT (Group Traversal Table) */
+ const nco_bool FORTRAN_IDX_CNV,      /* I [flg] Hyperslab indices obey Fortran convention */
+ const nco_bool MSA_USR_RDR,          /* I [flg] Multi-Slab Algorithm returns hyperslabs in user-specified order */
+ const nco_bool EXTRACT_ASSOCIATED_COORDINATES,  /* I [flg] Extract all coordinates associated with extracted variables? */
+ trv_tbl_sct * const trv_tbl);        /* I/O [sct] GTT (Group Traversal Table) */
 
 var_sct **                            /* O [sct] Variable list */  
 nco_fll_var_trv                       /* [fnc] Fill-in variable structure list for all extracted variables */
@@ -551,7 +551,8 @@ void
 nco_bld_rec_dmn                       /* [fnc] Build record dimensions array */
 (const int nc_id,                     /* I [ID] netCDF input file ID */
  const nco_bool FORTRAN_IDX_CNV,      /* I [flg] Hyperslab indices obey Fortran convention */
- const nco_bool flg_rec_all,          /* I [flg] Retrieve all records */
+ lmt_sct ***lmt_rec,                  /* I/O [lst] (ncra) Record dimensions */
+ int *nbr_rec,                        /* I/O [nbr] (ncra) Number of record dimensions (size of above array) */
  trv_tbl_sct * trv_tbl);              /* I/O [sct] GTT (Group Traversal Table) */
 
 void
@@ -682,9 +683,9 @@ nco_var_has_cf                        /* [fnc] Variable has CF-compliant informa
  nco_bool *flg_cf_fnd);               /* I/O [flg] CF variable was found */
 
 void
-nco_nsm_ncr                           /* [fnc] Increase ensembles (more than 1 file cases) */
-(const int nc_id,                     /* I [id] netCDF file ID */
- trv_tbl_sct * const trv_tbl);        /* I/O [sct] Traversal table */
+nco_chk_dmn                           /* [fnc] Check valid dimension names */
+(const int lmt_nbr,                   /* I [nbr] number of dimensions with limits */
+ nco_dmn_dne_t * flg_dne);            /* I [lst] Flag to check if input dimension -d "does not exist" */
 
 void
 nco_chk_dmn_in                        /* [fnc] Check input dimensions */
@@ -693,15 +694,11 @@ nco_chk_dmn_in                        /* [fnc] Check input dimensions */
  nco_dmn_dne_t **dne_lst,             /* I/O [lst] Flag to check if input dimension -d "does not exist" */
  const trv_tbl_sct * const trv_tbl);  /* I [sct] Traversal table */
 
-void
-nco_chk_dmn                           /* [fnc] Check valid dimension names */
-(const int lmt_nbr,                   /* I [nbr] number of dimensions with limits */
- nco_dmn_dne_t * flg_dne);            /* I [lst] Flag to check if input dimension -d "does not exist" */
-
 nco_bool                               /* O [flg] True if variable 1 is in scope of variable 2 */
 nco_var_scp                            /* [fnc] Is variable 1 is in scope of variable 2 */
 (const trv_sct * const var_trv_1,      /* I [sct] Variable 1 */
- const trv_sct * const var_trv_2);     /* I [sct] Variable 2 */
+ const trv_sct * const var_trv_2,      /* I [sct] Variable 2 */
+ const trv_tbl_sct * const trv_tbl);   /* I [sct] Traversal table */
 
 void
 nco_dmn_swap                           /* [fnc] Swap dimensions */
@@ -718,6 +715,85 @@ nco_dfn_dmn                            /* [fnc] Define dimension size and ID in
  dmn_cmn_sct *dmn_cmn,                 /* I/O [sct] Dimension structure array */
  const int nbr_dmn);                   /* I [nbr] Number of dimensions (size of above array) */
 
+int                                    /* O [enm] Comparison result [<,=,>] 0 iff val_1 [<,==,>] val_2 */
+nco_cmp_aux_crd_dpt                    /* [fnc] Compare two aux_crd_sct's by group depth */
+(const void *val_1,                    /* I [sct] aux_crd_sct * to compare */
+ const void *val_2);                   /* I [sct] aux_crd_sct * to compare */
+
+void
+nco_bld_crd_aux                        /* [fnc] Build auxiliary coordinates information into table */
+(const int nc_id,                      /* I [ID] netCDF file ID */
+ trv_tbl_sct *trv_tbl);                /* I [sct] GTT (Group Traversal Table) */
+
+void
+nco_lmt_aux_tbl                       /* [fnc] Apply limits to variable in table */
+(const int nc_id,                     /* I [ID] netCDF file ID */
+ lmt_sct **lmt,                       /* I [sct] Limits */
+ const int nbr_lmt,                   /* I [nbr] Number of limits */
+ const char * const var_nm_fll,       /* I [sng] Variable full name */
+ const int dmn_id,                    /* I [id] ID of dimension to apply the limits */
+ nco_bool FORTRAN_IDX_CNV,            /* I [flg] Hyperslab indices obey Fortran convention */
+ nco_bool MSA_USR_RDR,                /* I [flg] Multi-Slab Algorithm returns hyperslabs in user-specified order */
+ trv_tbl_sct * const trv_tbl);        /* I/O [sct] GTT (Group Traversal Table) */
+
+int *
+nco_dmn_malloc                         /* [fnc] Inquire about number of dimensions in group and return dynamic array of dimension IDs */
+(const int nc_id,                      /* I [ID] netCDF file ID */
+ const char * const grp_nm_fll,        /* I [sng] Group full name */
+ int *nbr_dmn);                        /* I/O [nbr] Number of dimensions in group */
+
+void
+nco_lmt_std_att_lat_lon               /* [fnc] Apply limits to variable in table that contains 'standard_name' attribute "latitude" */
+(const int nc_id,                     /* I [ID] netCDF file ID */
+ lmt_sct **lmt,                       /* I [sct] Limits */
+ const int nbr_nbr,                   /* I [nbr] Number of limits */
+ const int dmn_id,                    /* I [id] ID of dimension to apply the limits */
+ nco_bool FORTRAN_IDX_CNV,            /* I [flg] Hyperslab indices obey Fortran convention */
+ nco_bool MSA_USR_RDR,                /* I [flg] Multi-Slab Algorithm returns hyperslabs in user-specified order */
+ trv_tbl_sct * const trv_tbl);       /* I/O [sct] GTT (Group Traversal Table) */
+
+void
+nco_lmt_aux                           /* [fnc] Apply auxiliary -X limits (Auxiliary function called by different functions ) */
+(const int nc_id,                     /* I [ID] netCDF file ID */
+ lmt_sct **lmt,                       /* I [sct] Limits */
+ const int nbr_nbr,                   /* I [nbr] Number of limits */
+ nco_bool FORTRAN_IDX_CNV,            /* I [flg] Hyperslab indices obey Fortran convention */
+ nco_bool MSA_USR_RDR,                /* I [flg] Multi-Slab Algorithm returns hyperslabs in user-specified order */
+ const int idx_tbl,                   /* I [nbr] Table index */
+ const int idx_dmn,                   /* I [nbr] Dimension index */
+ trv_tbl_sct * const trv_tbl);        /* I/O [sct] GTT (Group Traversal Table) */
+
+void
+nco_prn_var                           /* [fnc] Print variable (debug only) */
+(const int nc_id,                     /* I [ID] netCDF file ID (Input or output file) */
+ trv_tbl_sct * const trv_tbl);        /* I/O [sct] Traversal table */
+
+void
+nco_dmn_lmt                            /* [fnc] Convert a lmt_sct array to dmn_sct (name only) */
+(lmt_sct **lmt,                        /* I [lst] lmt_sct array  */
+ const int nbr_lmt,                    /* I [nbr] Size of lmt_sct array  */
+ dmn_sct ***dmn);                      /* O [sct] dmn_sct array  */
+
+void
+nco_nsm_dfn_wrt                       /* [fnc] Define OR write ensemble fixed variables */
+(const int nc_id,                     /* I [ID] netCDF input file ID */
+ const int nc_out_id,                 /* I [ID] netCDF output file ID */
+ const cnk_sct * const cnk,           /* I [sct] Chunking structure */
+ const int dfl_lvl,                   /* I [enm] Deflate level [0..9] */
+ const gpe_sct * const gpe,           /* I [sct] GPE structure */
+ const nco_bool flg_def,              /* [fnc] Define OR write */
+ trv_tbl_sct * const trv_tbl);        /* I/O [sct] Traversal table */
+
+
+void
+nco_nsm_ncr                           /* [fnc] Increase ensembles (more than 1 file cases) */
+(const int nc_id,                     /* I [id] netCDF file ID */
+ trv_tbl_sct * const trv_tbl);        /* I/O [sct] Traversal table */
+
+void
+nco_prn_nsm                           /* [fnc] Print ensembles  */                                
+(const trv_tbl_sct * const trv_tbl);  /* I [sct] Traversal table */
+
 #ifdef __cplusplus
 } /* end extern "C" */
 #endif /* __cplusplus */
