@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_msa.c,v 1.236 2013/12/31 05:14:02 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_msa.c,v 1.238 2014/02/14 05:22:17 zender Exp $ */
 
 /* Purpose: Multi-slabbing algorithm */
 
@@ -585,12 +585,12 @@ nco_msa_lmt_all_ntl
     lmt_rgl->end=dmn_sz-1L;
     lmt_rgl->cnt=dmn_sz;
     lmt_rgl->srd=1L;
-    lmt_rgl->drn=1L;
+    lmt_rgl->ssc=1L;
     lmt_rgl->flg_mro=False;
     lmt_rgl->min_sng=NULL;
     lmt_rgl->max_sng=NULL;
     lmt_rgl->srd_sng=NULL;
-    lmt_rgl->drn_sng=NULL;
+    lmt_rgl->ssc_sng=NULL;
     lmt_rgl->mro_sng=NULL;
     lmt_rgl->rbs_sng=NULL;
     lmt_rgl->origin=0.0;
@@ -1265,7 +1265,7 @@ nco_cpy_var_val_mlt_lmt_trv         /* [fnc] Copy variable data from input to ou
 	   Too many other limits on string translation to list them all :)
 	   This only handles plain strings */
 	if(var_out.sz > 1L){
-	  (void)fprintf(stdout,"%s: ERROR Unable to autoconvert. %s reports string variable %s contains %li strings. Autoconversion of variables is currently limited to translating string variables that contain only one string. And even that it does incorrectly because each string is typically a distinct size, meaning a distinct phony dimension needs to be created for every string.\n",nco_prg_nm_get(),fnc_nm,var_nm,var_out.sz);
+	  (void)fprintf(stdout,"%s: ERROR Unable to autoconvert. %s reports string variable %s contains %li strings. Autoconversion of string variables is currently limited to string variables that contain a single string, not an array of strings. And even single strings are currently translated incorrectly because each string is typically a distinct size, meaning a distinct phony dimension would need to be created for every single string and NCO is loathe to do that. Complaints? Let us know.\n",nco_prg_nm_get(),fnc_nm,var_nm,var_out.sz);
 	  nco_exit(EXIT_FAILURE);
 	} /* endif err */
 
