@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_rth_utl.h,v 1.37 2013/09/19 03:35:18 pvicente Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_rth_utl.h,v 1.43 2014/01/03 19:44:44 zender Exp $ */
 
 /* Purpose: Arithmetic controls and utilities */
 
-/* Copyright (C) 1995--2013 Charlie Zender
+/* Copyright (C) 1995--2014 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -47,19 +47,22 @@ int /* O [enm] Arithmetic operation */
 nco_op_typ_get /* [fnc] Convert user-specified operation into operation key */
 (const char * const nco_op_sng); /* I [sng] User-specified operation */
 
+const char * /* O [enm] Arithmetic operation */
+nco_op_typ_cf_sng /* [fnc] Convert arithmetic operation type enum to string */
+(const int nco_op_typ); /* I [enm] Arithmetic operation type */
+
 void 
-nco_opr_nrm /* [fnc] Normalization of arithmetic operations for ncra/ncea */
+nco_opr_nrm /* [fnc] Normalization of arithmetic operations for ncra/nces */
 (const int nco_op_typ, /* I [enm] Operation type */
  const int nbr_var_prc, /* I [nbr] Number of processed variables */
  X_CST_PTR_CST_PTR_Y(var_sct,var_prc), /* I [sct] Variables in input file */
  X_CST_PTR_CST_PTR_Y(var_sct,var_prc_out), /* I/O [sct] Variables in output file */
- const nco_bool flg_nrm, /* I [flg] This record needs normalization */
- const char * const rec_nm_fll,      /* I [sng] Full name of record being done in loop (trv_tbl->lmt_rec[idx_rec]->nm_fll ) */
+ const char * const rec_nm_fll, /* I [sng] Full name of record dimension */
  const trv_tbl_sct * const trv_tbl); /* I [sct] Traversal table */
 
 void 
-nco_opr_drv /* [fnc] Intermediate control of arithmetic operations for ncra/ncea */
-(const long idx_rec, /* I [idx] Index of record (ncra) or file (ncea) in current operation group */
+nco_opr_drv /* [fnc] Intermediate control of arithmetic operations for ncra/nces */
+(const long idx_rec, /* I [idx] Index of record (ncra), file (ncfe), or group (ncge) in current operation */
  const int nco_op_typ, /* I [enm] Operation type */
  const var_sct * const var_prc, /* I [sct] Variable in input file */
  var_sct * const var_prc_out); /* I/O [sct] Variable in output file */
