@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_sng_utl.c,v 1.67 2013/12/31 05:14:02 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_sng_utl.c,v 1.72 2014/01/29 20:59:19 pvicente Exp $ */
 
 /* Purpose: String utilities */
 
@@ -15,36 +15,26 @@ strcasecmp /* [fnc] Lexicographical case-insensitive string comparison */
  const char * const sng_2) /* I [sng] Second string */
 {
   /* Copy of (const) input strings */
-  char *sng_1_c=strdup(sng_1);
-  char *sng_2_c=strdup(sng_2);
-
+  char *sng_1_c;
+  char *sng_2_c;
   char chr_1;
   char chr_2;
+
+  sng_1_c=(char *)sng_1;
+  sng_2_c=(char *)sng_2;
+
   while(1){
     chr_1=tolower(*sng_1_c++);
     chr_2=tolower(*sng_2_c++);
     if(chr_1 < chr_2){
-      /* Use free() not nco_free() to keep this more like a generic (non-NCO) library function */
-#ifndef _MSC_VER
-      sng_1_c=(char *)free(sng_1_c);
-      sng_2_c=(char *)free(sng_2_c);
-#endif /* _MSC_VER */
       return -1;
-    }
+    } /* end if */
     if(chr_1 > chr_2){
-#ifndef _MSC_VER
-      sng_1_c=(char *)free(sng_1_c);
-      sng_2_c=(char *)free(sng_2_c);
-#endif /* _MSC_VER */
       return 1;
-    }
+    } /* end if */
     if(chr_1 == 0){
-#ifndef _MSC_VER
-      sng_1_c=(char *)free(sng_1_c);
-      sng_2_c=(char *)free(sng_2_c);
-#endif
       return 0;
-    }
+    } /* end if */
   } /* end while */
 } /* end strcasecmp() */
 #endif /* !NEED_STRCASECMP */
