@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_var_lst.c,v 1.160 2013/11/06 01:37:18 pvicente Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_var_lst.c,v 1.166 2014/01/03 06:04:07 zender Exp $ */
 
 /* Purpose: Variable list utilities */
 
-/* Copyright (C) 1995--2013 Charlie Zender
+/* Copyright (C) 1995--2014 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -897,14 +897,14 @@ nco_var_lst_dvd /* [fnc] Divide input lists into output lists */
   /* Find operation type for each variable: for now this is either fix or prc */
   for(idx=0;idx<nbr_var;idx++){
 
-    /* nces case */
-    if (nco_prg_id == nces){
+    /* ncge case */
+    if(nco_prg_id == ncge){
       /* Mark all variables as fixed and later detect ensemble variable in table to mark as processed */
       var_op_typ[idx]=fix_typ;
     }else{
       /* Initialize operation type to processed. Change to fixed where warranted later. */
       var_op_typ[idx]=prc_typ;
-    } /* ! nces case */
+    } /* !ncge case */
 
     var_nm=var[idx]->nm;
     var_typ=var[idx]->type;
@@ -929,7 +929,7 @@ nco_var_lst_dvd /* [fnc] Divide input lists into output lists */
     case ncbo:
       if(var[idx]->is_crd_var || var_typ_fnk) var_op_typ[idx]=fix_typ;
       break;
-    case ncea:
+    case ncfe:
       if(var[idx]->is_crd_var || var_typ_fnk) var_op_typ[idx]=fix_typ;
       break;
     case ncecat:
@@ -948,11 +948,11 @@ nco_var_lst_dvd /* [fnc] Divide input lists into output lists */
     case ncra:
       if(!var[idx]->is_rec_var) var_op_typ[idx]=fix_typ;
       break;
-    case nces:
+    case ncge:
       /* Obtain variable GTT object using full variable name */
       var_trv=trv_tbl_var_nm_fll(var[idx]->nm_fll,trv_tbl);
       /* If variable is template, mark as processed */
-      if (var_trv->flg_nsm_tpl && var_trv->nco_typ == nco_obj_typ_var){
+      if(var_trv->flg_nsm_tpl && var_trv->nco_typ == nco_obj_typ_var){
         assert(var_trv->flg_nsm_mbr == True);
         var_op_typ[idx]=prc_typ;
       }
@@ -1028,7 +1028,7 @@ nco_var_lst_dvd /* [fnc] Divide input lists into output lists */
 	 However, this will miss (false-negative) the case when no variables 
 	 use an N-D coordinate-like variable as a coordinate. 
 	 And this may hit (false-positive) the record coordinate (often "time")
-	 which should be averaged by ncra, though perhaps not by ncea.
+	 which should be averaged by ncra, though perhaps not by nces.
 	 "coordinate-like" variables that should be "fixed", and not
 	 differenced, interpolated, or ensemble-averaged, include those 
 	 satisfying these conditions:
@@ -1078,7 +1078,7 @@ nco_var_lst_dvd /* [fnc] Divide input lists into output lists */
 
   /* fxm: Remove ncap exception when finished with ncap list processing */
   /* fxm: ncpdq processes all variables when packing requested */
-  if(*nbr_var_prc == 0 && nco_prg_id != ncap && nco_prg_id != ncpdq && nco_prg_id != nces){
+  if(*nbr_var_prc == 0 && nco_prg_id != ncap && nco_prg_id != ncpdq && nco_prg_id != ncge){
     (void)fprintf(stdout,"%s: ERROR no variables fit criteria for processing\n",nco_prg_nm_get());
     switch(nco_prg_id){
     case ncap:
@@ -1087,16 +1087,16 @@ nco_var_lst_dvd /* [fnc] Divide input lists into output lists */
       /* Do nothing */
       break;
     case ncbo:
-      (void)fprintf(stdout,"%s: HINT Extraction list must contain a non-coordinate variable that is not NC_CHAR, or NC_STRING in order to perform a binary operation (e.g., subtraction)\n",nco_prg_nm_get());
+      (void)fprintf(stdout,"%s: HINT Extraction list must contain a non-coordinate variable that is not NC_CHAR or NC_STRING in order to perform a binary operation (e.g., subtraction)\n",nco_prg_nm_get());
       break;
-    case ncea:
-      (void)fprintf(stdout,"%s: HINT Extraction list must contain a non-coordinate variable that is not NC_CHAR, or NC_STRING\n",nco_prg_nm_get());
+    case ncfe:
+      (void)fprintf(stdout,"%s: HINT Extraction list must contain a non-coordinate variable that is not NC_CHAR or NC_STRING\n",nco_prg_nm_get());
       break;
     case ncecat:
       (void)fprintf(stdout,"%s: HINT Extraction list must contain a non-coordinate variable\n",nco_prg_nm_get());
       break;
     case ncflint:
-      (void)fprintf(stdout,"%s: HINT Extraction list must contain a variable that is not NC_CHAR, or NC_STRING\n",nco_prg_nm_get());
+      (void)fprintf(stdout,"%s: HINT Extraction list must contain a variable that is not NC_CHAR or NC_STRING\n",nco_prg_nm_get());
       break;
     case ncks:
       /* Do nothing */
@@ -1105,7 +1105,7 @@ nco_var_lst_dvd /* [fnc] Divide input lists into output lists */
       (void)fprintf(stdout,"%s: HINT Extraction list must contain a variable that shares at least one dimension with the re-order list\n",nco_prg_nm_get());
       break;
     case ncra:
-      (void)fprintf(stdout,"%s: HINT Extraction list must contain a record variable that is not NC_CHAR, or NC_STRING\n",nco_prg_nm_get());
+      (void)fprintf(stdout,"%s: HINT Extraction list must contain a record variable that is not NC_CHAR or NC_STRING\n",nco_prg_nm_get());
       break;
     case ncrcat:
       (void)fprintf(stdout,"%s: HINT Extraction list must contain a record variable which to concatenate\n",nco_prg_nm_get());
@@ -1181,7 +1181,7 @@ nco_var_lst_dvd_trv                          /* [fnc] Divide input lists into ou
   case ncbo:
     if(var->is_crd_var || var_typ_fnk) var_op_typ=fix_typ;
     break;
-  case ncea:
+  case ncfe:
     if(var->is_crd_var || var_typ_fnk) var_op_typ=fix_typ;
     break;
   case ncecat:
@@ -1260,32 +1260,32 @@ nco_var_lst_dvd_trv                          /* [fnc] Divide input lists into ou
     /* NB: all !strcmp()'s except "msk_" which uses strstr() */
     if(is_sz_rnk_prv_rth_opr && (!strcmp(var_nm,"hyam") || !strcmp(var_nm,"hybm") || !strcmp(var_nm,"hyai") || !strcmp(var_nm,"hybi") || !strcmp(var_nm,"gw") || !strcmp(var_nm,"lon_bnds") || !strcmp(var_nm,"lat_bnds") || !strcmp(var_nm,"area") || !strcmp(var_nm,"ORO") || !strcmp(var_nm,"date") || !strcmp(var_nm,"datesec") || (strstr(var_nm,"msk_") == var_nm))) var_op_typ=fix_typ;
     /* Known "multi-dimensional coordinates" in CCSM-like model output:
-    lat, lon, lev are normally 1-D coordinates
-    Known exceptions:
-    lat and lon are "2-D coordinates" in NARCCAP output
-    NARCCAP specifies lat and lon in "coordinates" attribute of 2-D fields
-    latixy and longxy are "2-D coordinates" in CLM output
-    CLM does not specify latixy and longxy in "coordinates" attribute of any fields
-    NARCCAP output gives all "coordinate-like" fields an "axis" attribute
-    This includes the record coordinate (i.e., "time") which both ncra and ncwa _should_ process
-    CLM does not give an "axis" attribute to any fields
-    One method of chasing down all "coordinate-like" fields is to look
-    for the field name in the "coordinates" attribute of any variable.
-    However, this will miss (false-negative) the case when no variables 
-    use an N-D coordinate-like variable as a coordinate. 
-    And this may hit (false-positive) the record coordinate (often "time")
-    which should be averaged by ncra, though perhaps not by ncea.
-    "coordinate-like" variables that should be "fixed", and not
-    differenced, interpolated, or ensemble-averaged, include those 
-    satisfying these conditions:
-    0. Traditional coordinate (1-D variable same name as its dimension)
-    1. Present in a "coordinates" attribute (except "time" for ncra)
-    2. Present in a "bounds" attribute (except "time_bnds" for ncra)
-    3. Contain an "axis" attribute (except "time") fxm not done yet
-    4. Found in empirical list of variables
-    NB: In the above algorithm discussion, "time" is my shorthand 
-    for "the record variable, if any" */
-
+       lat, lon, lev are normally 1-D coordinates
+       Known exceptions:
+       lat and lon are "2-D coordinates" in NARCCAP output
+       NARCCAP specifies lat and lon in "coordinates" attribute of 2-D fields
+       latixy and longxy are "2-D coordinates" in CLM output
+       CLM does not specify latixy and longxy in "coordinates" attribute of any fields
+       NARCCAP output gives all "coordinate-like" fields an "axis" attribute
+       This includes the record coordinate (i.e., "time") which both ncra and ncwa _should_ process
+       CLM does not give an "axis" attribute to any fields
+       One method of chasing down all "coordinate-like" fields is to look
+       for the field name in the "coordinates" attribute of any variable.
+       However, this will miss (false-negative) the case when no variables 
+       use an N-D coordinate-like variable as a coordinate. 
+       And this may hit (false-positive) the record coordinate (often "time")
+       which should be averaged by ncra, though perhaps not by nces.
+       "coordinate-like" variables that should be "fixed", and not
+       differenced, interpolated, or ensemble-averaged, include those 
+       satisfying these conditions:
+       0. Traditional coordinate (1-D variable same name as its dimension)
+       1. Present in a "coordinates" attribute (except "time" for ncra)
+       2. Present in a "bounds" attribute (except "time_bnds" for ncra)
+       3. Contain an "axis" attribute (except "time") fxm not done yet
+       4. Found in empirical list of variables
+       NB: In the above algorithm discussion, "time" is my shorthand 
+       for "the record variable, if any" */
+    
     /* Conditions #1 and #2 are already implemented above in the case() statement */
     /* Check condition #4 above: */
     if(is_sz_rnk_prv_rth_opr && (!strcmp(var_nm,"lat") || !strcmp(var_nm,"lon") || !strcmp(var_nm,"lev") || !strcmp(var_nm,"longxy") || !strcmp(var_nm,"latixy") )) var_op_typ=fix_typ;
@@ -1310,4 +1310,3 @@ nco_var_lst_dvd_trv                          /* [fnc] Divide input lists into ou
   *prc=var_op_typ;
 
 } /* end nco_var_lst_dvd_trv */
-
