@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_var_utl.c,v 1.353 2013/12/31 05:14:02 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_var_utl.c,v 1.357 2014/02/14 05:22:17 zender Exp $ */
 
 /* Purpose: Variable utilities */
 
@@ -911,7 +911,15 @@ nco_var_free /* [fnc] Free all memory associated with variable structure */
   /* Purpose: Free all memory associated with a dynamically allocated variable structure */
 
   /* String values must be deep-free'd, everything else is a flat buffer */
-  if(var->type == (nc_type)NC_STRING && var->val.vp != (void *)NULL) var->val.vp=(void *)nco_sng_lst_free((char **)var->val.vp,var->sz); else var->val.vp=nco_free(var->val.vp);
+  if(var->type == (nc_type)NC_STRING){
+    /* 20140212: ncwa may free this memory twice because reduced variable not created correctly in nco_var_avg()
+       Temporarily only free string variables during debugging */
+    if(nco_dbg_lvl_get() == nco_dbg_crr)
+      if(var->val.vp) var->val.vp=(void *)nco_sng_lst_free((char **)var->val.vp,var->sz);
+  }else{
+    if(var->val.vp) var->val.vp=nco_free(var->val.vp);
+  } /* endif */
+
   var->nm=(char *)nco_free(var->nm);
   var->nm_fll=(char *)nco_free(var->nm_fll);
   var->mss_val.vp=nco_free(var->mss_val.vp);
@@ -1135,7 +1143,10 @@ nco_var_dfn /* [fnc] Define variables and write their attributes to output file
             if(deflate || shuffle) (void)nco_def_var_deflate(out_id,var[idx]->id,deflate,shuffle,dfl_lvl_in);
           } /* endif */
           /* Overwrite HDF Lempel-Ziv compression level, if requested */
-          if(dfl_lvl >= 0) (void)nco_def_var_deflate(out_id,var[idx]->id,(int)True,(int)True,dfl_lvl);
+	  if(dfl_lvl == 0) deflate=(int)False; else deflate=(int)True;
+	  /* Turn-off shuffle when uncompressing otherwise chunking requests may fail */
+	  if(dfl_lvl == 0) shuffle=(int)False; 
+          if(dfl_lvl >= 0) (void)nco_def_var_deflate(out_id,var[idx]->id,shuffle,deflate,dfl_lvl);
         } /* endif */
       } /* endif netCDF4 */
 
@@ -1495,7 +1506,7 @@ nco_var_mtd_refresh /* [fnc] Update variable metadata (dmn_nbr, ID, mss_val, typ
 
 void
 nco_var_srd_srt_set /* [fnc] Assign zero to start and unity to stride vectors in variables */
-(var_sct ** const var, /* I [sct] Variables whose duration, start, and stride arrays to set */
+(var_sct ** const var, /* I [sct] Variables whose subcycle, start, and stride arrays to set */
  const int nbr_var) /* I [nbr] Number of structures in variable structure list */
 {
   /* Purpose: Zero start (srt) and stride (srd) arrays of variable 
